<?php

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
/**
 *
 * Header Widget .
 *
 */
class Taxiar_Header extends Widget_Base {

	public function get_name() {
		return 'taxiarheader';
	}
	public function get_title() {
		return __( 'Header', 'taxiar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'taxiar_header_elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'layout_section',
			[
				'label' 	=> __( 'Header', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
			'layout_style',
			[
				'label' 	=> __( 'Layout Style', 'taxiar' ),
				'type' 		=> Controls_Manager::SELECT,
				'options' 	=> [
					'1' => __( 'Style One', 'taxiar' ),
					'2' => __( 'Style Two', 'taxiar' ),
				],
				'default' => '1',
			]
        );

		$this->add_control(
			'show_top_bar',
			[
				'label' 		=> __( 'Show Top Bar?', 'taxiar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'taxiar' ),
				'label_off' 	=> __( 'Hide', 'taxiar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);

		$this->add_control(
			'topbar_email_icon',
			[
				'label' 		=> __( 'Email Icon', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXT,
				'label_block' 	=> true,
				'default' 		=> '<i class="fa-thin fa-envelope"></i>',
				'condition'		=> [ 
					'show_top_bar'  => ['yes'],
				],
			]
		);

		$this->add_control(
			'topbar_email',
			[
				'label' 	=> __( 'Email Address', 'taxiar' ),
				'type' 		=> Controls_Manager::TEXT,
				'default' 	=> __( 'info@taxiar.com', 'taxiar' ),
				'label_block' => true,
				'separator'		=> 'after',
				'condition'		=> [ 
					'show_top_bar'  => ['yes'],
				],
			]
		);

		$this->add_control(
			'topbar_phone_icon',
			[
				'label' 		=> __( 'Phone Icon', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXT,
				'label_block' 	=> true,
				'default' 		=> '<i class="fa-thin fa-phone"></i>',
				'condition'		=> [ 
					'show_top_bar'  => ['yes'],
				],
			]
		);

		$this->add_control(
			'topbar_phone',
			[
				'label' 	=> __( 'Phone Number', 'taxiar' ),
				'type' 		=> Controls_Manager::TEXT,
				'default' 	=> __( '(+468) 254 762 443', 'taxiar' ),
				'label_block' => true,
				'separator'		=> 'after',
				'condition'		=> [ 
					'show_top_bar'  => ['yes'], 
				],
			]
		);

		$this->add_control(
			'topbar_address_icon',
			[
				'label' 		=> __( 'Address Iocn', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXT,
				'label_block' 	=> true,
				'default' 		=> '<i class="fa-thin fa-map-location-dot"></i>',
				'condition'		=> [ 
					'show_top_bar'  => ['yes'],
					'layout_style' => ['2']
				],
			]
		);
		$this->add_control(
			'topbar_address',
			[
				'label' 	=> __( 'Address', 'taxiar' ),
				'type' 		=> Controls_Manager::TEXT,
				'default' 	=> __( '25 Street,
				145 City, USA', 'taxiar' ),
				'label_block' => true,
				'separator'		=> 'after',
				'condition'		=> [ 
					'show_top_bar'  => ['yes'],
					'layout_style' => ['2']
				],
			]
		);

		//Social 
		$this->add_control(
			'show_social',
			[
				'label' 		=> __( 'Show Social?', 'taxiar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'taxiar' ),
				'label_off' 	=> __( 'Hide', 'taxiar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
				'separator'		=> 'before',
				'condition'		=> [ 
					'show_top_bar'  => ['yes'],
				],
			]
		);

		$this->add_control(
			'social_text',
			[
				'label' 	=> __( 'Social Text', 'taxiar' ),
				'type' 		=> Controls_Manager::TEXT,
				'default' 	=> __( 'Follow Us On:', 'taxiar' ),
				'label_block' => true,
				'condition'		=> [ 
					'show_social'  => 'yes',
					'show_top_bar'  => ['yes'],
				],
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'social_icon',
			[
				'label' 	=> __( 'Social Icon', 'taxiar' ),
				'type' 		=> Controls_Manager::ICONS,
				'default' 	=> [
					'value' 	=> 'fab fa-facebook-f',
					'library' 	=> 'solid',
				],
			]
		);

		$repeater->add_control(
			'icon_link',
			[
				'label' 		=> __( 'Link', 'taxiar' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> __( 'https://your-link.com', 'taxiar' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> true,
				],
			]
		);

		$this->add_control(
			'social_icon_list',
			[
				'label' 		=> __( 'Social Icon', 'taxiar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'social_icon' => __( 'Add Social Icon','taxiar' ),
					],
				],
				'condition'		=> [ 
					'show_social'  => 'yes',
					'show_top_bar'  => ['yes'],
				],
			]
		);

		$this->add_control(
			'logo_image',

			[
				'label' 		=> __( 'Upload Logo', 'taxiar' ),
				'type' 			=> Controls_Manager::MEDIA,
			]
		);		

		$menus = $this->taxiar_menu_select();

		if( !empty( $menus ) ){
	        $this->add_control(
				'taxiar_menu_select',
				[
					'label'     	=> __( 'Select Taxiar Menu', 'taxiar' ),
					'type'      	=> Controls_Manager::SELECT,
					'options'   	=> $menus,
					'description' 	=> sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to manage your menus.', 'taxiar' ), admin_url( 'nav-menus.php' ) ),
				]
			);
		}else {
			$this->add_control(
				'no_menu',
				[
					'type' 				=> Controls_Manager::RAW_HTML,
					'raw' 				=> '<strong>' . __( 'There are no menus in your site.', 'taxiar' ) . '</strong><br>' . sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to create one.', 'taxiar' ), admin_url( 'nav-menus.php?action=edit&menu=0' ) ),
					'separator' 		=> 'after',
					'content_classes' 	=> 'elementor-panel-alert elementor-panel-alert-info',
				]
			);
		}

		$this->add_control(
			'show_search_btn',
			[
				'label' 		=> __( 'Show Search Button?', 'taxiar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'taxiar' ),
				'label_off' 	=> __( 'Hide', 'taxiar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);		

		$this->add_control(
			'show_cart_btn',
			[
				'label' 		=> __( 'Show Cart Button?', 'taxiar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'taxiar' ),
				'label_off' 	=> __( 'Hide', 'taxiar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
				'separator'		=> 'before',
			]
		);

		$this->add_control(
			'show_offcanvas_btn',
			[
				'label' 		=> __( 'Show Offcanvas Button?', 'taxiar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'taxiar' ),
				'label_off' 	=> __( 'Hide', 'taxiar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
				'separator'		=> 'before',
			]
		);

		$this->add_control(
			'show_btn',
			[
				'label' 		=> __( 'Show Button?', 'taxiar' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'taxiar' ),
				'label_off' 	=> __( 'Hide', 'taxiar' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);

		$this->add_control(
			'button_text',
			[
				'label' 		=> __( 'Button Text', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXT,
				'label_block' 	=> true,
				'default' 	=> __( 'REGISTER NOW', 'taxiar' ),
				'condition'		=> [
					'show_btn' => [ 'yes' ],
				],
			]
		);

		$this->add_control(
			'button_url',
			[
				'label' 		=> esc_html__( 'Button Link', 'taxiar' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> esc_html__( 'https://your-link.com', 'taxiar' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
				'condition'		=> [
					'show_btn' => [ 'yes' ],
				],
			]
		);

        $this->end_controls_section();

		//---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------------------------General Style-----------------------//
		 $this->start_controls_section(
			'general_styling',
			[
				'label'     => __( 'Background Styling', 'taxiar' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'header_top_bg',
			[
				'label' 		=> __( 'Topbar Background', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .header-top' => 'background-color: {{VALUE}} !important;',
                ],
			]
        );    

		$this->add_control(
			'header_social_bg',
			[
				'label' 		=> __( 'Social Background', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .header-layout8 .header-top .header-social:before' => 'background-color: {{VALUE}} !important;',
                ],
				'condition'		=> [ 
					'layout_style' => ['1']
				],
			]
        );  

        $this->add_control(
			'header_logo_bg',
			[
				'label' 		=> __( 'Logo Background', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .header-layout8 .logo-bg:before, {{WRAPPER}} .header-layout9 .logo-bg:after' => 'background-color: {{VALUE}} !important;',
                ],
			]
        );    

        $this->add_control(
			'header_logo_bg2',
			[
				'label' 		=> __( 'Logo Shape', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .header-layout9 .logo-bg:before' => 'background-color: {{VALUE}} !important;',
                ],
				'condition'		=> [ 
					'layout_style' => ['2']
				],
			]
        );    

        $this->add_control(
			'header_menu_bg',
			[
				'label' 		=> __( 'Menu Background', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .sticky-wrapper' => 'background-color: {{VALUE}} !important;',
                ],
			]
        );    

		$this->end_controls_section();

		//-------------------------Menu Bar Style-----------------------//
        $this->start_controls_section(
			'menubar_styling3',
			[
				'label'     => __( 'Menu Styling', 'taxiar' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'menu_text_color',
			[
				'label' 			=> __( 'Menu Text Color', 'taxiar' ),
				'type' 				=> Controls_Manager::COLOR,
				'selectors' 		=> [
					'{{WRAPPER}} .main-menu>ul>li>a' => 'color: {{VALUE}};',
                ]
			]
        );

        $this->add_control(
			'menu_text_hover_color',
			[
				'label' 			=> __( 'Menu Hover Color', 'taxiar' ),
				'type' 				=> Controls_Manager::COLOR,
				'selectors' 		=> [
					'{{WRAPPER}} .main-menu>ul>li>a:hover' => 'color: {{VALUE}};',
                ]
			]
        );

        $this->add_control(
			'dropdown_text_color',
			[
				'label' 			=> __( 'Dropdown Text Color', 'taxiar' ),
				'type' 				=> Controls_Manager::COLOR,
				'selectors' 		=> [
					'{{WRAPPER}} .main-menu ul.sub-menu li a' => 'color: {{VALUE}};',
                ]
			]
        );

        $this->add_control(
			'dropdown_text_hover_color',
			[
				'label' 			=> __( 'Dropdown Hover Color', 'taxiar' ),
				'type' 				=> Controls_Manager::COLOR,
				'selectors' 		=> [
					'{{WRAPPER}} .main-menu ul.sub-menu li a:hover' => 'color: {{VALUE}};',
                ]
			]
        );

		$this->add_control(
			'dropdown_icon_color',
			[
				'label' 			=> __( 'Dropdown Icon Color', 'taxiar' ),
				'type' 				=> Controls_Manager::COLOR,
				'selectors' 		=> [
					'{{WRAPPER}} .main-menu ul.sub-menu li a:before' => 'color: {{VALUE}} !important;',
                ]
			]
        );

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 			=> 'menu_typography',
				'label' 		=> __( 'Menu Typography', 'taxiar' ),
                'selector' 		=> '{{WRAPPER}} .main-menu>ul>li>a, {{WRAPPER}} .main-menu ul.sub-menu li a',
			]
		);

        $this->add_responsive_control(
			'menu_margin',
			[
				'label' 		=> __( 'Menu Margin', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .main-menu>ul>li>a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ]
			]
        );

        $this->add_responsive_control(
			'menu_padding',
			[
				'label' 		=> __( 'Menu Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .main-menu>ul>li>a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ]
			]
		);

		$this->end_controls_section();

		//-------------------------Button Style-----------------------//
		$this->start_controls_section(
			'button_style_section',
			[
				'label' 	=> __( 'Button Style', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'button_typography',
				'label' 	=> __( 'Typography', 'taxiar' ),
				'selector' 	=> '{{WRAPPER}} .th_btn',
			]
		);

		$this->start_controls_tabs(
			'style_tabs'
		);

			$this->start_controls_tab(
				'first_style_tab',
				[
					'label' => esc_html__( 'Normal', 'taxiar' ),
				]
			);

			$this->add_control(
				'button_color',
				[
					'label' 		=> __( 'Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn' => 'color: {{VALUE}}',
					],
				]
			);
	
			$this->add_control(
				'button_bg',
				[
					'label' 		=> __( 'Background Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn' => 'background-color:{{VALUE}}',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border',
					'selector' => '{{WRAPPER}} .th_btn',
				]
			);

			$this->end_controls_tab();

			//--------------------secound--------------------//
			$this->start_controls_tab(
				'sec_style_tab',
				[
					'label' => esc_html__( 'Hover', 'taxiar' ),
				]
			);

			$this->add_control(
				'button_h_color',
				[
					'label' 		=> __( 'Hover Color ', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn:hover' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'button_h_bg',
				[
					'label' 		=> __( 'Background Hover Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn:before, {{WRAPPER}} .th_btn:after' => 'background-color:{{VALUE}} !important',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border2',
					'selector' => '{{WRAPPER}} .th_btn:hover',
				]
			);

			$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_control(
			'hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_responsive_control(
			'button_margin',
			[
				'label' 		=> __( 'Margin', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th_btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->add_responsive_control(
			'button_padding',
			[
				'label' 		=> __( 'Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th_btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);
		
		$this->add_responsive_control(
			'button_border_radius',
			[
				'label' 		=> __( 'Border Radius', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th_btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->end_controls_section();

    }

    public function taxiar_menu_select(){
	    $taxiar_menu = wp_get_nav_menus();
	    $menu_array  = array();
		$menu_array[''] = __( 'Select A Menu', 'taxiar' );
	    foreach( $taxiar_menu as $menu ){
	        $menu_array[ $menu->slug ] = $menu->name;
	    }
	    return $menu_array;
	}

	protected function render() {

        $settings = $this->get_settings_for_display();

		global $woocommerce;

        //Menu by menu select
        $taxiar_avaiable_menu   = $this->taxiar_menu_select();
		if( ! $taxiar_avaiable_menu ){
			return;
		}
		$args = [
			'menu' 			=> $settings['taxiar_menu_select'],
			'menu_class' 	=> 'taxiar-menu',
			'container' 	=> '',
		];
		
		//Sticky header on/off
		if(taxiar_opt( 'taxiar_header_sticky_switcher' )){
            $sticky_class  = 'yes-sticky';
        }else{
            $sticky_class  = 'no-sticky';
        }

		$email    	= $settings['topbar_email'];
		$phone    	= $settings['topbar_phone'];        

		$email          = is_email( $email );

		$replace        = array(' ','-',' - ');
		$replace_phone        = array(' ','-',' - ', '(', ')');
		$with           = array('','','');

		$emailurl       = str_replace( $replace, $with, $email );
		$phoneurl       = str_replace( $replace_phone, $with, $phone );	

		//Mobile menu, Offcanvas, Search
        echo taxiar_mobile_menu();
		echo taxiar_header_cart_offcanvas();
		echo taxiar_header_offcanvas();
		echo taxiar_search_box();
		?>

		<?php if( $settings['layout_style'] == '2' ): ?>
			<div class="th-header header-layout9 header-absolute">
				<?php if(!empty( $settings['show_top_bar'])): ?>
				<div class="header-top">
					<div class="container">
						<div class="row justify-content-center justify-content-lg-between align-items-center gy-2">
							<div class="col-auto">
								<div class="header-links">
									<ul>
											<li><?php echo wp_kses_post($settings['topbar_email_icon']); ?><a href="<?php echo esc_attr('mailto:' . $emailurl); ?>"><?php echo esc_html($email); ?></a>
											</li>
											<li><?php echo wp_kses_post($settings['topbar_phone_icon']); ?><a href="<?php echo esc_attr('tel:' . $phoneurl); ?>"><?php echo esc_html($phone); ?></a>
											</li>
											<li class="d-none d-xxl-inline-block"><?php echo wp_kses_post($settings['topbar_address_icon']); ?><?php echo esc_html($settings['topbar_address']); ?></li>
									</ul>
								</div>
							</div>
							<?php if(!empty( $settings['show_social'])): ?>
							<div class="col-auto">
								<div class="header-social">
									<span class="social-title"><?php echo esc_html($settings['social_text']); ?></span>
									<?php	 
										foreach( $settings['social_icon_list'] as $social_icon ): 
										$social_target    = $social_icon['icon_link']['is_external'] ? ' target="_blank"' : '';
										$social_nofollow  = $social_icon['icon_link']['nofollow'] ? ' rel="nofollow"' : '';
									?>
										<a <?php echo esc_html($social_target) ?> <?php echo esc_html($social_nofollow) ?> href="<?php echo esc_url( $social_icon['icon_link']['url'] ) ?>"> <?php \Elementor\Icons_Manager::render_icon( $social_icon['social_icon'], [ 'aria-hidden' => 'true' ] ); ?></a> 
									<?php endforeach; ?>
								</div>
							</div>
							<?php endif; ?>
						</div>
					</div>
				</div>
				<?php endif; ?>
				<div class="sticky-wrapper <?php echo esc_attr( $sticky_class ); ?>">
					<!-- Main Menu Area -->
					<div class="menu-area">
						<div class="container">
							<div class="row justify-content-between align-items-center">
								<div class="col-auto">
									<div class="header-logo">
									<a href="<?php echo esc_url( home_url( '/' ) ) ?>">
											<?php echo taxiar_img_tag( array(
												'url'   => esc_url( $settings['logo_image']['url']  ),
											)); ?>
										</a>
									</div>
								</div>
								<div class="col-auto ms-xl-auto">
									<nav class="main-menu d-none d-lg-block">
										<?php if( ! empty( $settings['taxiar_menu_select'] ) ){
											wp_nav_menu( $args );
										} ?>
									</nav>
									<button class="th-menu-toggle  d-inline-block d-lg-none"><i class="far fa-bars"></i></button>
								</div>
								<div class="col-auto d-none d-xl-block">
									<div class="header-button">
										<?php if(!empty( $settings['show_search_btn'])): ?>
											<button type="button" class="icon-btn searchBoxToggler"><i class="far fa-search"></i></button>
										<?php endif; ?>
										<?php 
											if(!empty( $settings['show_cart_btn'])): 
												if( ! empty( $woocommerce->cart->cart_contents_count ) ){
													$count = $woocommerce->cart->cart_contents_count;
												}else{
													$count = "0";
												}
										?>
										<button type="button" class="icon-btn sideMenuToggler2">
											<i class="fa-regular fa-bag-shopping"></i>
											<span class="badge"><?php echo esc_html( $count ); ?></span>
										</button>
										<?php endif; ?>
										<?php if(!empty( $settings['show_offcanvas_btn'])): ?>
											<a href="#" class="icon-btn sideMenuToggler"><i class="far fa-bars"></i></a>
										<?php endif; ?>
										<?php if(!empty( $settings['show_btn'])): ?>
											<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="th-btn style3 radius-btn2 th_btn"><?php echo wp_kses_post($settings['button_text']); ?></a>
										<?php endif; ?>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="logo-bg"></div>
				</div>
			</div>
	
		<?php else: ?>
			<div class="th-header header-layout8 header-absolute">
				<?php if(!empty( $settings['show_top_bar'])): ?>
				<div class="header-top">
					<div class="container">
						<div class="row justify-content-center justify-content-lg-between align-items-center gy-2">
							<?php if(!empty( $settings['show_social'])): ?>
							<div class="col-auto">
								<div class="header-social">
									<span class="social-title"><?php echo esc_html($settings['social_text']); ?></span>
									<?php	 
										foreach( $settings['social_icon_list'] as $social_icon ): 
										$social_target    = $social_icon['icon_link']['is_external'] ? ' target="_blank"' : '';
										$social_nofollow  = $social_icon['icon_link']['nofollow'] ? ' rel="nofollow"' : '';
									?>
										<a <?php echo esc_html($social_target) ?> <?php echo esc_html($social_nofollow) ?> href="<?php echo esc_url( $social_icon['icon_link']['url'] ) ?>"> <?php \Elementor\Icons_Manager::render_icon( $social_icon['social_icon'], [ 'aria-hidden' => 'true' ] ); ?></a> 
									<?php endforeach; ?>
								</div>
							</div>
							<?php endif; ?>
							<div class="col-auto">
								<div class="header-right">
									<div class="header-links">
										<ul>
											<li><?php echo wp_kses_post($settings['topbar_email_icon']); ?><a href="<?php echo esc_attr('mailto:' . $emailurl); ?>"><?php echo esc_html($email); ?></a>
											</li>
											<li><?php echo wp_kses_post($settings['topbar_phone_icon']); ?><a href="<?php echo esc_attr('tel:' . $phoneurl); ?>"><?php echo esc_html($phone); ?></a>
											</li>
										</ul>
									</div>
									<div class="langauge lang-dropdown">
										<a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink1" data-bs-toggle="dropdown" aria-expanded="false"><?php echo esc_html__( 'Language', 'taxiar' );?></a>
											<div class="list dropdown-menu" aria-labelledby="dropdownMenuLink1">
												<?php  echo do_shortcode('[gtranslate]'); ?>
											</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
				<?php endif; ?>
				<div class="sticky-wrapper <?php echo esc_attr( $sticky_class ); ?>">
					<!-- Main Menu Area -->
					<div class="menu-area">
						<div class="container">
							<div class="row justify-content-between align-items-center">
								<div class="col-auto">
									<div class="header-logo">
										<a href="<?php echo esc_url( home_url( '/' ) ) ?>">
											<?php echo taxiar_img_tag( array(
												'url'   => esc_url( $settings['logo_image']['url']  ),
											)); ?>
										</a>
									</div>
								</div>
								<div class="col-auto">
									<nav class="main-menu d-none d-lg-block">
										<?php if( ! empty( $settings['taxiar_menu_select'] ) ){
											wp_nav_menu( $args );
										} ?>
									</nav>
									<button class="th-menu-toggle  d-inline-block d-lg-none"><i class="far fa-bars"></i></button>
								</div>
								<div class="col-auto d-none d-xl-block">
									<div class="header-button">
										<?php if(!empty( $settings['show_search_btn'])): ?>
											<button type="button" class="icon-btn searchBoxToggler"><i class="far fa-search"></i></button>
										<?php endif; ?>
										<?php 
											if(!empty( $settings['show_cart_btn'])): 
												if( ! empty( $woocommerce->cart->cart_contents_count ) ){
													$count = $woocommerce->cart->cart_contents_count;
												}else{
													$count = "0";
												}
										?>
										<button type="button" class="icon-btn sideMenuToggler2">
											<i class="fa-regular fa-bag-shopping"></i>
											<span class="badge"><?php echo esc_html( $count ); ?></span>
										</button>
										<?php endif; ?>
										<?php if(!empty( $settings['show_offcanvas_btn'])): ?>
											<a href="#" class="icon-btn sideMenuToggler"><i class="far fa-bars"></i></a>
										<?php endif; ?>
										<?php if(!empty( $settings['show_btn'])): ?>
											<div class="header-button">
												<a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="th-btn radius-btn th_btn"><?php echo wp_kses_post($settings['button_text']); ?></a>
											</div>
										<?php endif; ?>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="logo-bg"></div>
				</div>
			</div>

		<?php endif; 

	}
}