<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Group_Control_Border;
/**
 *
 * Banner Widget.
 *
 */
class taxiar_Banner extends Widget_Base {

	public function get_name() {
		return 'taxiarbanner';
	}
	public function get_title() {
		return __( 'Banner', 'taxiar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'taxiar_header_elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'banner_section',
			[
				'label' 	=> __( 'Banner', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

		$this->add_control(
			'layout_style',
			[
				'label' 		=> __( 'Layout Style', 'taxiar' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> '1',
				'options' 		=> [
					'1'  		=> __( 'Style One', 'taxiar' ),
					'2' 		=> __( 'Style Two', 'taxiar' ),
					'3' 		=> __( 'Style Three', 'taxiar' ),
				],
			]
		);

		$this->add_control(
            'image',
            [
                'label'     => __( 'Image', 'taxiar' ),
                'type'      => Controls_Manager::MEDIA,
                'dynamic' 		=> [
					'active' 		=> true,
				],
				'condition'	=> [
					'layout_style' => ['3']
				]	
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'banner_img',
            [
                'label'     => __( 'Banner Image', 'taxiar' ),
                'type'      => Controls_Manager::MEDIA,
                'dynamic' 		=> [
					'active' 		=> true,
				],
				'default' 		=> [
					'url' 		=> Utils::get_placeholder_image_src(),
				],
            ]
        );

        $repeater->add_control(
            'overlay_img',
            [
                'label'     => __( 'Overlay Image', 'taxiar' ),
                'type'      => Controls_Manager::MEDIA,
                'dynamic' 		=> [
					'active' 		=> true,
				],
            ]
        );

        $repeater->add_control(
			'banner_subtitle', [
				'label' 		=> __( 'Sub Title', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( 'Subtitle here' , 'taxiar' ),
				'label_block' 	=> true,
				'separator' => 'before',
			]
        );

        $repeater->add_control(
			'banner_title', [
				'label' 		=> __( 'Title', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( 'Title here' , 'taxiar' ),
				'label_block' 	=> true,
			]
        );

		$repeater->add_control(
			'banner_desc', [
				'label' 		=> __( 'Description', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 4,
				'default' 		=> __( 'Description here' , 'taxiar' ),
				'label_block' 	=> true,
			]
        );

        $repeater->add_control(
			'button_text',
			[
				'label' 	=> esc_html__( 'Button Text', 'taxiar' ),
                'type' 		=> Controls_Manager::TEXT,
                'default'  	=> esc_html__( 'Apply Now', 'taxiar' ),
				'label_block' => true,
				'separator' => 'before'
			]
        );

        $repeater->add_control(
			'button_link',
			[
				'label' 		=> esc_html__( 'Button Link', 'taxiar' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> esc_html__( 'https://your-link.com', 'taxiar' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
			]
		);

		$this->add_control(
			'banner_slides',
			[
				'label' 		=> __( 'Banners', 'taxiar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'banner_subtitle' 	=> __( 'WELCOME TO TAXIAR', 'taxiar' ),
						'banner_title' 		=> __( 'The Best Way To Get Around Town.', 'taxiar' ),
					],
				],		
				'condition'	=> [
					'layout_style' => ['1']
				]			
			]
		);

		$repeater2 = new Repeater();

        $repeater2->add_control(
            'banner_img',
            [
                'label'     => __( 'Banner Image', 'taxiar' ),
                'type'      => Controls_Manager::MEDIA,
                'dynamic' 		=> [
					'active' 		=> true,
				],
				'default' 		=> [
					'url' 		=> Utils::get_placeholder_image_src(),
				],
            ]
        );
        $repeater2->add_control(
            'overlay_img',
            [
                'label'     => __( 'Overlay Image', 'taxiar' ),
                'type'      => Controls_Manager::MEDIA,
                'dynamic' 		=> [
					'active' 		=> true,
				],
            ]
        );

		$repeater2->add_control(
			'video_link',
			[
				'label' 		=> esc_html__( 'Video Link', 'taxiar' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> esc_html__( 'https://your-link.com', 'taxiar' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
			]
		);

        $repeater2->add_control(
			'banner_title', [
				'label' 		=> __( 'Title', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( 'Title here' , 'taxiar' ),
				'label_block' 	=> true,
			]
        );

        $repeater2->add_control(
			'banner_title2', [
				'label' 		=> __( 'Title 2', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( 'Title 2 here' , 'taxiar' ),
				'label_block' 	=> true,
			]
        );

		$repeater2->add_control(
			'banner_desc', [
				'label' 		=> __( 'Description', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 4,
				'default' 		=> __( 'Description here' , 'taxiar' ),
				'label_block' 	=> true,
			]
        );

        $repeater2->add_control(
			'button_text',
			[
				'label' 	=> esc_html__( 'Button Text', 'taxiar' ),
                'type' 		=> Controls_Manager::TEXT,
                'default'  	=> esc_html__( 'Apply Now', 'taxiar' ),
				'label_block' => true,
				'separator' => 'before'
			]
        );

        $repeater2->add_control(
			'button_link',
			[
				'label' 		=> esc_html__( 'Button Link', 'taxiar' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> esc_html__( 'https://your-link.com', 'taxiar' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
			]
		);

		$repeater2->add_control(
			'button_text2',
			[
				'label' 	=> esc_html__( 'Button Text', 'taxiar' ),
                'type' 		=> Controls_Manager::TEXT,
                'default'  	=> esc_html__( 'Apply Now', 'taxiar' ),
				'label_block' => true,
				'separator' => 'before'
			]
        );

        $repeater2->add_control(
			'button_link2',
			[
				'label' 		=> esc_html__( 'Button Link', 'taxiar' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> esc_html__( 'https://your-link.com', 'taxiar' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
			]
		);

		$this->add_control(
			'banner_slides_2',
			[
				'label' 		=> __( 'Banners', 'taxiar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater2->get_controls(),
				'default' 		=> [
					[
						'banner_title' 		=> __( 'The Best Way To Get Around Town.', 'taxiar' ),
					],
				],		
				'condition'	=> [
					'layout_style' => ['2']
				]			
			]
		);

		$repeater3 = new Repeater();

        $repeater3->add_control(
            'banner_img',
            [
                'label'     => __( 'Banner Image', 'taxiar' ),
                'type'      => Controls_Manager::MEDIA,
                'dynamic' 		=> [
					'active' 		=> true,
				],
				'default' 		=> [
					'url' 		=> Utils::get_placeholder_image_src(),
				],
            ]
        );

        $repeater3->add_control(
			'banner_title', [
				'label' 		=> __( 'Title', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 2,
				'default' 		=> __( 'Title here' , 'taxiar' ),
				'label_block' 	=> true,
			]
        );

		$repeater3->add_control(
			'banner_desc', [
				'label' 		=> __( 'Description', 'taxiar' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'rows' 			=> 4,
				'default' 		=> __( 'Description here' , 'taxiar' ),
				'label_block' 	=> true,
			]
        );

        $repeater3->add_control(
			'button_text',
			[
				'label' 	=> esc_html__( 'Button Text', 'taxiar' ),
                'type' 		=> Controls_Manager::TEXT,
                'default'  	=> esc_html__( 'Apply Now', 'taxiar' ),
				'label_block' => true,
				'separator' => 'before'
			]
        );

        $repeater3->add_control(
			'button_link',
			[
				'label' 		=> esc_html__( 'Button Link', 'taxiar' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> esc_html__( 'https://your-link.com', 'taxiar' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
			]
		);

		$repeater3->add_control(
			'button_text2',
			[
				'label' 	=> esc_html__( 'Button Text', 'taxiar' ),
                'type' 		=> Controls_Manager::TEXT,
                'default'  	=> esc_html__( 'Apply Now', 'taxiar' ),
				'label_block' => true,
				'separator' => 'before'
			]
        );

        $repeater3->add_control(
			'button_link2',
			[
				'label' 		=> esc_html__( 'Button Link', 'taxiar' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> esc_html__( 'https://your-link.com', 'taxiar' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
			]
		);

		$this->add_control(
			'banner_slides_3',
			[
				'label' 		=> __( 'Banners', 'taxiar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater3->get_controls(),
				'default' 		=> [
					[
						'banner_title' 		=> __( 'The Best Way To Get Around Town.', 'taxiar' ),
					],
				],		
				'condition'	=> [
					'layout_style' => ['3']
				]			
			]
		);

		$this->end_controls_section();


        //---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------------------------Content Style-----------------------//
		$this->start_controls_section(
			'tab_styling',
			[
				'label' 	=> __( 'Content Styling', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs(
			'style_tabs'
		);

			$this->start_controls_tab(
				'first_style_tab',
				[
					'label' => esc_html__( 'Sub Title', 'taxiar' ),	
				]
			);

			$this->add_control(
				'first_tab_color',
				[
					'label' 		=> __( 'Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th-sub'	=> 'color: {{VALUE}}!important;',
					],
				]
			);

			$this->add_control(
				'first_tab_color2',
				[
					'label' 		=> __( 'Lines Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th-sub:before, {{WRAPPER}}  .th-sub:after'	=> 'background-color: {{VALUE}}!important;',
					],
				]
			);

			$this->add_group_control(
			Group_Control_Typography::get_type(),
					[
					'name' 			=> 'first_tab_typography',
						'label' 		=> __( 'Typography', 'taxiar' ),
						'selector' 	=> '{{WRAPPER}} .th-sub',
				]
			);

			$this->add_responsive_control(
				'first_tab_margin',
				[
					'label' 		=> __( 'Margin', 'taxiar' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .th-sub' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'first_tab_padding',
				[
					'label' 		=> __( 'Padding', 'taxiar' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .th-sub' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->end_controls_tab();

			//--------------------secound--------------------//
			$this->start_controls_tab(
				'sec_style_tab',
				[
					'label' => esc_html__( 'Title', 'taxiar' ),
				]
			);

			$this->add_control(
				'sec_tab_color',
				[
					'label' 		=> __( 'Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th-title'	=> 'color: {{VALUE}}!important;',
					],
				]
			);

			$this->add_group_control(
			Group_Control_Typography::get_type(),
					[
					'name' 			=> 'sec_tab_typography',
						'label' 		=> __( 'Typography', 'taxiar' ),
						'selector' 	=> '{{WRAPPER}} .th-title',
				]
			);

			$this->add_responsive_control(
				'sec_tab_margin',
				[
					'label' 		=> __( 'Margin', 'taxiar' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .th-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'sec_tab_padding',
				[
					'label' 		=> __( 'Padding', 'taxiar' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .th-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->end_controls_tab();

			//--------------------threth--------------------//
			$this->start_controls_tab(
				'third_style_tab',
				[
					'label' => esc_html__( 'Description', 'taxiar' ),
				]
			);

			$this->add_control(
				'third_tab_color',
				[
					'label' 		=> __( 'Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th-desc'	=> 'color: {{VALUE}}!important;',
					],
				]
			);

			$this->add_group_control(
			Group_Control_Typography::get_type(),
					[
					'name' 			=> 'third_tab_typography',
						'label' 		=> __( 'Typography', 'taxiar' ),
						'selector' 	=> '{{WRAPPER}} .th-desc',
				]
			);

			$this->add_responsive_control(
				'third_tab_margin',
				[
					'label' 		=> __( 'Margin', 'taxiar' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .th-desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'third_tab_padding',
				[
					'label' 		=> __( 'Padding', 'taxiar' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .th-desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->end_controls_tab();

		$this->end_controls_tabs();
		$this->end_controls_section();
	
		//-------------------------Button Style-----------------------//
		$this->start_controls_section(
			'button_style_section',
			[
				'label' 	=> __( 'Button Style', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'button_typography',
				'label' 	=> __( 'Typography', 'taxiar' ),
				'selector' 	=> '{{WRAPPER}} .th_btn',
			]
		);

		$this->start_controls_tabs(
			'button_style_tabs'
		);

			$this->start_controls_tab(
				'normal_style_tab',
				[
					'label' => esc_html__( 'Normal', 'taxiar' ),
				]
			);

			$this->add_control(
				'button_color',
				[
					'label' 		=> __( 'Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'button_bg',
				[
					'label' 		=> __( 'Background Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn' => 'background-color:{{VALUE}}',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border',
					'selector' => '{{WRAPPER}} .th_btn',
				]
			);

			$this->end_controls_tab();

			//--------------------secound--------------------//
			$this->start_controls_tab(
				'hover_style_tab',
				[
					'label' => esc_html__( 'Hover', 'taxiar' ),
				]
			);

			$this->add_control(
				'button_h_color',
				[
					'label' 		=> __( 'Hover Color ', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn:hover' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'button_h_bg',
				[
					'label' 		=> __( 'Background Hover Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn:before, {{WRAPPER}} .th_btn:after' => 'background-color:{{VALUE}} !important',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border2',
					'selector' => '{{WRAPPER}} .th_btn:hover',
				]
			);

			$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_control(
			'hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_responsive_control(
			'button_margin',
			[
				'label' 		=> __( 'Margin', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th_btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->add_responsive_control(
			'button_padding',
			[
				'label' 		=> __( 'Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th_btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->add_responsive_control(
			'button_border_radius',
			[
				'label' 		=> __( 'Border Radius', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th_btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->end_controls_section();

		//-------------------------Button 2 Style-----------------------//
		$this->start_controls_section(
			'button_style_section2',
			[
				'label' 	=> __( 'Button 2 Style', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
				'condition'	=> [
					'layout_style' => ['2', '3']
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'button_typography2',
				'label' 	=> __( 'Typography', 'taxiar' ),
				'selector' 	=> '{{WRAPPER}} .th_btn2',
			]
		);

		$this->start_controls_tabs(
			'button_style_tabs2'
		);

			$this->start_controls_tab(
				'normal_style_tab2',
				[
					'label' => esc_html__( 'Normal', 'taxiar' ),
				]
			);

			$this->add_control(
				'button_color2',
				[
					'label' 		=> __( 'Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn2' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'button_bg2',
				[
					'label' 		=> __( 'Background Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn2' => 'background-color:{{VALUE}}',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border3',
					'selector' => '{{WRAPPER}} .th_btn2',
				]
			);

			$this->end_controls_tab();

			//--------------------secound--------------------//
			$this->start_controls_tab(
				'hover_style_tab2',
				[
					'label' => esc_html__( 'Hover', 'taxiar' ),
				]
			);

			$this->add_control(
				'button_h_color2',
				[
					'label' 		=> __( 'Hover Color ', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn2:hover' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'button_h_bg2',
				[
					'label' 		=> __( 'Background Hover Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn2:before, {{WRAPPER}} .th_btn2:after' => 'background-color:{{VALUE}} !important',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border4',
					'selector' => '{{WRAPPER}} .th_btn2:hover',
				]
			);

			$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_control(
			'hr2',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_responsive_control(
			'button_margin2',
			[
				'label' 		=> __( 'Margin', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th_btn2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->add_responsive_control(
			'button_padding2',
			[
				'label' 		=> __( 'Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th_btn2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->add_responsive_control(
			'button_border_radius2',
			[
				'label' 		=> __( 'Border Radius', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th_btn2' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->end_controls_section();


    }

	protected function render() {

    $settings = $this->get_settings_for_display();

	?>
	<?php if( $settings['layout_style'] == '2' ): ?>
		<div class="th-hero-wrapper  hero-8">
			<div class="hero-slider-8 th-carousel" id="heroSlide8" data-slide-show="1" data-md-slide-show="1" data-fade="true">
				<?php foreach( $settings['banner_slides_2'] as $data ): ?>
				<div class="th-hero-slide">
					<div class="th-hero-bg" data-bg-src="<?php echo esc_url($data['banner_img']['url']); ?>">
						<?php echo taxiar_img_tag( array(
							'url'   => esc_url( $data['overlay_img']['url']  ),
						)); ?>
					</div>
					<div class="container">
						<div class="hero-style8">
							<?php if(!empty( $data['video_link']['url'])): ?>
							<div class="video-btn" data-ani="slideindown" data-ani-delay="0.2s">
								<a href="<?php echo esc_url( $data['video_link']['url'] ) ?>" class="hero-play-btn popup-video"><i class="fas fa-play"></i></a>
							</div>
							<?php endif; ?>
							<h1 class="hero-title mb-0 th-title" data-ani="slideinleft" data-ani-delay="0.4s"><?php echo wp_kses_post($data['banner_title']) ?></h1>
							<h1 class="hero-title text-theme th-title" data-ani="slideinleft" data-ani-delay="0.5s"><?php echo wp_kses_post($data['banner_title2']) ?></h1>
							<p class="hero-text th-desc" data-ani="slideinleft" data-ani-delay="0.6s"><?php echo wp_kses_post($data['banner_desc']); ?></p>
							<div class="btn-group" data-ani="slideinup" data-ani-delay="0.7s">
								<?php if(!empty($data['button_text'])): ?>
								<a href="<?php echo esc_url( $data['button_link']['url'] ); ?>" class="th-btn style3 th_btn radius-btn"><span class="btn-text"><?php echo wp_kses_post($data['button_text']); ?></span></a>
								<?php endif; ?>
								<?php if(!empty($data['button_text2'])): ?>
								<a href="<?php echo esc_url( $data['button_link2']['url'] ); ?>" class="th-btn style2 th_btn2 radius-btn"><span class="btn-text"><?php echo wp_kses_post($data['button_text2']); ?></span></a>
								<?php endif; ?>
							</div>
						</div>
					</div>
				</div>
				<?php endforeach; ?>
			</div>
			<div class="icon-box">
				<button data-slick-prev="#heroSlide8" class="slick-arrow default"><i class="fa-regular fa-arrow-left"></i></button>
				<button data-slick-next="#heroSlide8" class="slick-arrow default"><i class="fa-regular fa-arrow-right"></i></button>
			</div>
		</div>

	<?php elseif($settings['layout_style'] == '3' ): ?>
		<div class="th-hero-wrapper  hero-9">
        <div class="hero-slider-9 th-carousel" id="heroSlide9" data-slide-show="1" data-md-slide-show="1" data-fade="true">
			<?php foreach( $settings['banner_slides_3'] as $data ): ?>
            <div class="th-hero-slide">
                <div class="th-hero-bg">
                    <div class="hero-img" data-ani="slideinright" data-ani-delay="0.9s">
						<?php echo taxiar_img_tag( array(
							'url'   => esc_url( $data['banner_img']['url']  ),
						)); ?>
                    </div>
                </div>
                <div class="container">
                    <div class="hero-style9">
                        <h1 class="hero-title th-title" data-ani="slideinleft" data-ani-delay="0.4s">
							<?php echo wp_kses_post($data['banner_title']) ?>
						</h1>
                        <p class="hero-text th-desc" data-ani="slideinleft" data-ani-delay="0.6s">
							<?php echo wp_kses_post($data['banner_desc']); ?>
						</p>
                        <div class="btn-group" data-ani="slideinup" data-ani-delay="0.7s">
							<?php if(!empty($data['button_text'])): ?>
                            	<a href="<?php echo esc_url( $data['button_link']['url'] ); ?>" class="th-btn style3 radius-btn2"><span class="btn-text"><?php echo wp_kses_post($data['button_text']); ?></span></a>
							<?php endif; ?>
							<?php if(!empty($data['button_text2'])): ?>
                        		<a href="<?php echo esc_url( $data['button_link2']['url'] ); ?>" class="th-btn style2 radius-btn2"><span class="btn-text"><?php echo wp_kses_post($data['button_text2']); ?></span></a>
							<?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
			<?php endforeach; ?>
        </div>
        <div class="icon-box">
            <button data-slick-prev="#heroSlide9" class="slick-arrow default"><i class="fa-regular fa-arrow-left"></i></button>
            <button data-slick-next="#heroSlide9" class="slick-arrow default"><i class="fa-regular fa-arrow-right"></i></button>
        </div>
        <div class="hero-overlay">
			<?php echo taxiar_img_tag( array(
					'url'   => esc_url( $settings['image']['url']  ),
				)); ?>
		</div>
    </div>


	<?php else: ?>
		<div class="th-hero-wrapper  hero-slider-7 th-carousel" data-slide-show="1" data-md-slide-show="1" data-fade="true" data-dots="true" data-xl-dots="true" data-ml-dots="true" data-lg-dots="true">
			<?php foreach( $settings['banner_slides'] as $data ): ?>
			<div class="th-hero-slide">
				<div class="th-hero-bg " data-bg-src="<?php echo esc_url($data['banner_img']['url']); ?>">
					<?php echo taxiar_img_tag( array(
						'url'   => esc_url( $data['overlay_img']['url']  ),
					)); ?>
				</div>
				<div class="container">
					<div class="hero-style7">
						<span class="hero-subtitle th-sub" data-ani="slideinleft" data-ani-delay="0.1s"><?php echo wp_kses_post($data['banner_subtitle']) ?></span>
						<h1 class="hero-title th-title" data-ani="slideinleft" data-ani-delay="0.3s"><?php echo wp_kses_post($data['banner_title']) ?></h1>
						<p class="hero-text th-desc" data-ani="slideinleft" data-ani-delay="0.4s"><?php echo wp_kses_post($data['banner_desc']); ?></p>
						<?php if(!empty($data['button_text'])): ?>
						<div class="btn-group" data-ani="slideinleft" data-ani-delay="0.5s">
							<a href="<?php echo esc_url( $data['button_link']['url'] ); ?>" class="th-btn th_btn style3"><?php echo wp_kses_post($data['button_text']); ?></a>
						</div>
						<?php endif; ?>
					</div>
				</div>
			</div>
			<?php endforeach; ?>
		</div>

	<?php endif; 
		
	}

}