<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Border;
use \Elementor\Utils;
/**
 *
 * Blog Post Widget .
 *
 */
class taxiar_Blog extends Widget_Base {

	public function get_name() {
		return 'taxiarblog';
	}
	public function get_title() {
		return __( 'Blog Post', 'taxiar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'taxiar' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'blog_post_section',
			[
				'label' => __( 'Blog Post', 'taxiar' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
			'layout_style',
			[
				'label' 	=> __( 'Layout Style', 'taxiar' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '1',
				'options' 	=> [
					'1'  		=> __( 'Style One', 'taxiar' ),
					'2' 		=> __( 'Style Two', 'taxiar' ),
					'3' 		=> __( 'Style Three', 'taxiar' ),
				],
				'separator' => 'after'
			]
		);

        $this->add_control(
			'blog_post_count',
			[
				'label' 	=> __( 'No of Post to show', 'taxiar' ),
                'type' 		=> Controls_Manager::NUMBER,
                'min'       => 1,
                'max'       => count( get_posts( array('post_type' => 'post', 'post_status' => 'publish', 'fields' => 'ids', 'posts_per_page' => '-1') ) ),
                'default'  	=> __( '4', 'taxiar' )
			]
        );

		$this->add_control(
			'title_count',
			[
				'label' 	=> __( 'Title Length', 'taxiar' ),
				'type' 		=> Controls_Manager::TEXT,
				'default'  	=> __( '5', 'taxiar' ),
			]
		);

		// $this->add_control(
		// 	'excerpt_count',
		// 	[
		// 		'label' 	=> __( 'Excerpt Length', 'taxiar' ),
		// 		'type' 		=> Controls_Manager::TEXT,
		// 		'default'  	=> __( '16', 'taxiar' ),
		// 	]
		// );

        $this->add_control(
			'blog_post_order',
			[
				'label' 	=> __( 'Order', 'taxiar' ),
                'type' 		=> Controls_Manager::SELECT,
                'options'   => [
                    'ASC'   	=> __('ASC','taxiar'),
                    'DESC'   	=> __('DESC','taxiar'),
                ],
                'default'  	=> 'DESC'
			]
        );

        $this->add_control(
			'blog_post_order_by',
			[
				'label' 	=> __( 'Order By', 'taxiar' ),
                'type' 		=> Controls_Manager::SELECT,
                'options'   => [
                    'ID'    	=> __( 'ID', 'taxiar' ),
                    'author'    => __( 'Author', 'taxiar' ),
                    'title'    	=> __( 'Title', 'taxiar' ),
                    'date'    	=> __( 'Date', 'taxiar' ),
                    'rand'    	=> __( 'Random', 'taxiar' ),
                ],
                'default'  	=> 'ID'
			]
        );

        $this->add_control(
			'exclude_cats',
			[
				'label' 		=> __( 'Exclude Categories', 'taxiar' ),
                'type' 			=> Controls_Manager::SELECT2,
                'multiple' 		=> true,
				'options' 		=> $this->taxiar_get_categories(),
			]
        );

        $this->add_control(
			'exclude_tags',
			[
				'label' 		=> __( 'Exclude Tags', 'taxiar' ),
                'type' 			=> Controls_Manager::SELECT2,
                'multiple' 		=> true,
				'options' 		=> $this->taxiar_get_tags(),
			]
        );

        $this->add_control(
			'exclude_post_id',
			[
				'label'         => __( 'Exclude Post', 'taxiar' ),
                'type'          => Controls_Manager::SELECT2,
                'multiple'      => true,
				'options'       => $this->taxiar_post_id(),
			]
        );

        $this->add_control(
			'read_more',
			[
				'label' 	=> __( 'Read More Text', 'taxiar' ),
                'type' 		=> Controls_Manager::TEXTAREA,
				'rows'	=> 3,
                'default'  	=> __( 'Read More', 'taxiar' ),
			]
        );

        $this->end_controls_section();

		//---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------------------------Content Style-----------------------//
		$this->start_controls_section(
			'tab_styling',
			[
				'label' 	=> __( 'Content Styling', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs(
			'style_tabs'
		);

			$this->start_controls_tab(
				'first_style_tab',
				[
					'label' => esc_html__( 'Title', 'taxiar' ),
				]
			);

			$this->add_control(
				'first_tab_color',
				[
					'label' 		=> __( 'Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th-title a'	=> 'color: {{VALUE}}!important;',
					],
				]
			);
			
			$this->add_control(
				'first_tab_color2',
				[
					'label' 		=> __( 'Hover Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th-title a:hover'	=> 'color: {{VALUE}}!important;',
					],
				]
			);

			$this->add_group_control(
			Group_Control_Typography::get_type(),
					[
					'name' 			=> 'first_tab_typography',
						'label' 		=> __( 'Typography', 'taxiar' ),
						'selector' 	=> '{{WRAPPER}} .th-title',
				]
			);

			$this->add_responsive_control(
				'first_tab_margin',
				[
					'label' 		=> __( 'Margin', 'taxiar' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .th-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'first_tab_padding',
				[
					'label' 		=> __( 'Padding', 'taxiar' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .th-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->end_controls_tab();

			//--------------------secound--------------------//
			$this->start_controls_tab(
				'sec_style_tab',
				[
					'label' => esc_html__( 'Content', 'taxiar' ),
					'condition'	=> [
						'layout_style' => ['4']
					]
				]
			);

			$this->add_control(
				'sec_tab_color',
				[
					'label' 		=> __( 'Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th-desc'	=> 'color: {{VALUE}}!important;',
					],
				]
			);

			$this->add_group_control(
			Group_Control_Typography::get_type(),
					[
					'name' 			=> 'sec_tab_typography',
						'label' 		=> __( 'Typography', 'taxiar' ),
						'selector' 	=> '{{WRAPPER}} .th-desc',
				]
			);

			$this->add_responsive_control(
				'sec_tab_margin',
				[
					'label' 		=> __( 'Margin', 'taxiar' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .th-desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_responsive_control(
				'sec_tab_padding',
				[
					'label' 		=> __( 'Padding', 'taxiar' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .th-desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->end_controls_tab();

			//--------------------threth--------------------//
			$this->start_controls_tab(
				'third_style_tab',
				[
					'label' => esc_html__( 'Button', 'taxiar' ),
				]
			);

			$this->add_control(
				'third_tab_color',
				[
					'label' 		=> __( 'Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn'	=> '--theme-color: {{VALUE}}!important;',
					],
				]
			);

			$this->add_control(
				'third_tab_bg',
				[
					'label' 		=> __( 'Hover Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn:hover'	=> '--theme-color: {{VALUE}}!important;',
					],
				]
			);

			$this->add_group_control(
			Group_Control_Typography::get_type(),
					[
					'name' 			=> 'third_tab_typography',
						'label' 		=> __( 'Typography', 'taxiar' ),
						'selector' 	=> '{{WRAPPER}} .th_btn',
				]
			);

			$this->add_responsive_control(
				'third_tab_margin',
				[
					'label' 		=> __( 'Margin', 'taxiar' ),
					'type' 			=> Controls_Manager::DIMENSIONS,
					'size_units' 	=> [ 'px', '%', 'em' ],
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->end_controls_tab();

		$this->end_controls_tabs();
		$this->end_controls_section();

    }

    public function taxiar_get_categories() {
        $cats = get_terms(array(
            'taxonomy' => 'category',
            'hide_empty' => true,
        ));

        $catarr = [];

        foreach( $cats as $singlecat ) {
            $catarr[$singlecat->term_id] = __($singlecat->name,'taxiar');
        }

        return $catarr;
    }

    public function taxiar_get_tags() {
        $cats = get_terms(array(
            'taxonomy' => 'post_tag',
            'hide_empty' => true,
        ));

        $catarr = [];

        foreach( $cats as $singlecat ) {
            $catarr[$singlecat->term_id] = __($singlecat->name,'taxiar');
        }

        return $catarr;
    }

    // Get Specific Post
    public function taxiar_post_id(){
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => -1,
        );

        $taxiar_post = new WP_Query( $args );

        $postarray = [];

        while( $taxiar_post->have_posts() ){
            $taxiar_post->the_post();
            $postarray[get_the_Id()] = get_the_title();
        }
        wp_reset_postdata();
        return $postarray;
    }

	protected function render() {

        $settings = $this->get_settings_for_display();
        $exclude_post = $settings['exclude_post_id'];

        if( !empty( $settings['exclude_cats'] ) && empty( $settings['exclude_tags'] ) && empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'category__not_in'      => $settings['exclude_cats']
            );
        } elseif( !empty( $settings['exclude_cats'] ) && !empty( $settings['exclude_tags'] ) && empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'category__not_in'      => $settings['exclude_cats'],
                'tag__not_in'           => $settings['exclude_tags']
            );
        }elseif( !empty( $settings['exclude_cats'] ) && !empty( $settings['exclude_tags'] ) && !empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'category__not_in'      => $settings['exclude_cats'],
                'tag__not_in'           => $settings['exclude_tags'],
                'post__not_in'          => $exclude_post
            );
        } elseif( !empty( $settings['exclude_cats'] ) && empty( $settings['exclude_tags'] ) && !empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'category__not_in'      => $settings['exclude_cats'],
                'post__not_in'          => $exclude_post
            );
        } elseif( empty( $settings['exclude_cats'] ) && !empty( $settings['exclude_tags'] ) && !empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'tag__not_in'           => $settings['exclude_tags'],
                'post__not_in'          => $exclude_post
            );
        } elseif( empty( $settings['exclude_cats'] ) && !empty( $settings['exclude_tags'] ) && empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'tag__not_in'           => $settings['exclude_tags'],
            );
        } elseif( empty( $settings['exclude_cats'] ) && empty( $settings['exclude_tags'] ) && !empty( $settings['exclude_post_id'] ) ) {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true,
                'post__not_in'          => $exclude_post
            );
        } else {
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => esc_attr( $settings['blog_post_count'] ),
                'order'                 => esc_attr( $settings['blog_post_order'] ),
                'orderby'               => esc_attr( $settings['blog_post_order_by'] ),
                'ignore_sticky_posts'   => true
            );
        }

    $blogpost = new WP_Query( $args );

	?>
	<?php if( $settings['layout_style'] == '2' ): ?>
		<div class="blog-grid-wrap">
			<?php  
				while( $blogpost->have_posts() ): 
				$blogpost->the_post(); 
				$categories = get_the_category();
			?>
	    	<div class="blog-grid style3">
				<div class="blog-img">
					<?php the_post_thumbnail(); ?>
					<a class="blog-date" href="<?php echo esc_url( taxiar_blog_date_permalink() ); ?>"><span class="month"><?php echo esc_html( get_the_date('d') ); ?></span> <?php echo esc_html( get_the_date( 'M, Y' ) ) ?></a>
				</div>
				<div class="blog-content">
					<div class="blog-meta style2">
						<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta('ID') ) ); ?>"><?php echo esc_html__('By ', 'taxiar') . esc_html( ucwords( get_the_author() ) ); ?></a>
						<a href="#">
						<?php 
							if(get_comments_number() == 1){
								echo esc_html__('Comment(', 'taxiar'); 
							}else{
								echo esc_html__('Comments(', 'taxiar'); 
							}
							echo get_comments_number(); ?>)
						</a>
					</div>
					<h3 class="blog-title th-title"><a href="<?php echo esc_url( get_permalink() ); ?>"><?php echo esc_html( wp_trim_words( get_the_title( ), $settings['title_count'], '' ) ); ?></a></h3>
					<?php if(!empty($settings['read_more'])): ?>
						<a href="<?php echo esc_url( get_permalink() ); ?>" class="link-btn th_btn"><?php echo wp_kses_post($settings['read_more']); ?></a>
					<?php endif; ?>
				</div>
			</div>
			<?php endwhile; wp_reset_postdata();  ?>
		</div>

	<?php elseif( $settings['layout_style'] == '3' ): ?>
		<div class="recent-post-wrap">
			<?php  
				while( $blogpost->have_posts() ): 
				$blogpost->the_post(); 
				$categories = get_the_category();
			?>
			<div class="recent-post">
				<div class="media-img">
					<a href="<?php echo esc_url( get_permalink() ); ?>">
						<?php echo taxiar_img_tag( array(
							"url"   => esc_url( get_the_post_thumbnail_url( null, 'taxiar_95X90' ) ),
						) ); ?>
					</a>
				</div>
				<div class="media-body">
					<div class="recent-post-meta">
						<a href="<?php echo esc_url( taxiar_blog_date_permalink() ); ?>"><i class="far fa-calendar-days"></i><?php echo esc_html( get_the_date( 'd M, Y' ) ) ?></a>
					</div>
					<h4 class="post-title th-title"><a class="text-inherit" href="<?php echo esc_url( get_permalink() ); ?>"><?php echo esc_html( wp_trim_words( get_the_title( ), $settings['title_count'], '' ) ); ?></a></h4>
					<a href="<?php echo esc_url( get_permalink() ); ?>" class="line-btn th_btn"><?php echo wp_kses_post($settings['read_more']); ?></a>
				</div>
			</div>
			<?php endwhile; wp_reset_postdata();  ?>
		</div>
		
	<?php else: ?>
		<div class="row th-carousel slider-shadow arrow-wrap" data-slide-show="3" data-lg-slide-show="2" data-md-slide-show="2" data-sm-slide-show="1" data-arrows="true" data-xl-arrows="true" data-ml-arrows="true">
			<?php  
				while( $blogpost->have_posts() ): 
				$blogpost->the_post(); 
				$categories = get_the_category();
			?>
			<div class="col-md-6 col-xl-4">
				<div class="blog-item wow fadeInUp">
					<?php if(has_post_thumbnail()):?>
					<div class="blog-img">
						<?php the_post_thumbnail( 'taxiar_327X220' ); ?>
						<a class="blog-date" href="<?php echo esc_url( taxiar_blog_date_permalink() ); ?>"><span class="month"><?php echo esc_html( get_the_date('d') ); ?></span> <?php echo esc_html( get_the_date( 'M, Y' ) ) ?></a>
					</div>
					<?php endif; ?>
					<div class="blog-content">
						<div class="blog-meta style2">
							<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta('ID') ) ); ?>"><?php echo esc_html__('By ', 'taxiar') . esc_html( ucwords( get_the_author() ) ); ?></a>
							<a href="#">
							<?php 
                                if(get_comments_number() == 1){
                                    echo esc_html__('Comment(', 'taxiar'); 
                                }else{
                                    echo esc_html__('Comments(', 'taxiar'); 
                                }
                                echo get_comments_number(); ?>)
							</a>
						</div>
						<h3 class="blog-item_title th-title"><a href="<?php echo esc_url( get_permalink() ); ?>"><?php echo esc_html( wp_trim_words( get_the_title( ), $settings['title_count'], '' ) ); ?></a></h3>
						<?php if(!empty($settings['read_more'])): ?>
							<a href="<?php echo esc_url( get_permalink() ); ?>" class="link-btn th_btn"><?php echo wp_kses_post($settings['read_more']); ?></a>
						<?php endif; ?>
					</div>
				</div>
			</div>
			<?php endwhile; wp_reset_postdata();  ?>
		</div>
		
	<?php endif; 
      
	}
}