<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * features Widget .
 *
 */
class Taxiar_Features extends Widget_Base {

	public function get_name() {
		return 'taxiarfeatures';
	}
	public function get_title() {
		return __( 'features', 'taxiar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'taxiar' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'arrow_section',
			[
				'label'     => __( 'features', 'taxiar' ),
				'tab'       => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
			'layout_style',
			[
				'label' 	=> __( 'Layout Style', 'taxiar' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '1',
				'options' 	=> [
					'1'  		=> __( 'Style One', 'taxiar' ),
					'2' 		=> __( 'Style Two', 'taxiar' ),
					'3' 		=> __( 'Style Three', 'taxiar' ),
					// '4' 		=> __( 'Style Four', 'taxiar' ),
				],
			]
		);
	
		$repeater = new Repeater();

		$repeater->add_control(
			'icon',
			[
				'label' 		=> __( 'Choose Image', 'taxiar' ),
				'type' 			=> Controls_Manager::MEDIA,
				'dynamic' 		=> [
					'active' 		=> true,
				],
				'default' 		=> [
					'url' 			=> Utils::get_placeholder_image_src(),
				],
			]
		); 

        $repeater->add_control(
			'title',
            [
				'label'         => __( 'Title', 'taxiar' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'Title' , 'taxiar' ),
				'label_block'   => true,
				'rows' => '2'
			]
		);

        $repeater->add_control(
			'desc',
            [
				'label'         => __( 'Description', 'taxiar' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'Description' , 'taxiar' ),
				'label_block'   => true,
				'rows' => '4'
			]
		);

		$this->add_control(
			'features_list',
			[
				'label' 		=> __( 'Features List', 'taxiar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'title' 		=> __( 'Creative Team', 'taxiar' ),
					],
				],
				'condition'	=> [
					'layout_style' => ['1', '3'],
				]
			]
		);

		$repeater2 = new Repeater();

		$repeater2->add_control(
			'title',
            [
				'label'         => __( 'Title', 'taxiar' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'Title' , 'taxiar' ),
				'label_block'   => true,
				'rows' => '2'
			]
		);

		$repeater2->add_control(
			'desc',
            [
				'label'         => __( 'Description', 'taxiar' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'Description' , 'taxiar' ),
				'label_block'   => true,
				'rows' => '4'
			]
		);

		$repeater2->add_control(
			'image',
			[
				'label' 		=> __( 'Choose Image', 'taxiar' ),
				'type' 			=> Controls_Manager::MEDIA,
				'dynamic' 		=> [
					'active' 		=> true,
				],
				'default' 		=> [
					'url' 			=> Utils::get_placeholder_image_src(),
				],
			]
		); 

		$repeater2->add_control(
			'feature',
			[
				'label' 	=> __( 'Faq Answer', 'taxiar' ),
                'type' 		=> Controls_Manager::WYSIWYG,
                'default'  	=> __( 'Morbi condimentum congue dui, elementum maximus augue porttitor', 'taxiar' )
			]
        );

		$repeater2->add_control(
			'button_text',
			[
				'label' 	=> esc_html__( 'Button Text', 'taxiar' ),
                'type' 		=> Controls_Manager::TEXT,
                'default'  	=> esc_html__( 'Apply Now', 'taxiar' ),
				'label_block' => true,
				'separator' => 'before'
			]
        );

        $repeater2->add_control(
			'button_link',
			[
				'label' 		=> esc_html__( 'Button Link', 'taxiar' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> esc_html__( 'https://your-link.com', 'taxiar' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
			]
		);

		$this->add_control(
			'features_list_2',
			[
				'label' 		=> __( 'Features List', 'taxiar' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater2->get_controls(),
				'default' 		=> [
					[
						'title' 		=> __( 'Creative Team', 'taxiar' ),
					],
				],
				'condition'	=> [
					'layout_style' => ['2'],
				]
			]
		);

        $this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------	

		//-------------------------Title Style-----------------------//
		$this->start_controls_section(
			'title_style',
			[
				'label' 	=> __( 'Title Style', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
				'condition'	=> [
					'layout_style' => ['1', '3'],
				]
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' 		=> __( 'Color', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .th-title' => 'color: {{VALUE}} !important',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'title_typography',
				'label' 	=> __( 'Typography', 'taxiar' ),
				'selector' 	=> '{{WRAPPER}} .th-title',
			]
		);

		$this->add_responsive_control(
			'title_margin',
			[
				'label' 		=> __( 'Margin', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->add_responsive_control(
			'title_padding',
			[
				'label' 		=> __( 'Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->end_controls_section();

		//-------------------------Description Style-----------------------//
		$this->start_controls_section(
			'desc_style',
			[
				'label' 	=> __( 'Description Style', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
				'condition'	=> [
					'layout_style' => ['1', '3'],
				]	
			]
		);

		$this->add_control(
			'desc_color',
			[
				'label' 		=> __( 'Color', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .th-desc' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'desc_typography',
				'label' 	=> __( 'Typography', 'taxiar' ),
				'selector' 	=> '{{WRAPPER}} .th-desc',
			]
		);

		$this->add_responsive_control(
			'desc_margin',
			[
				'label' 		=> __( 'Margin', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th-desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->add_responsive_control(
			'desc_padding',
			[
				'label' 		=> __( 'Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th-desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->end_controls_section();

	}

	protected function render() {

    $settings = $this->get_settings_for_display();
    ?>
        <?php if( $settings['layout_style'] == '2' ): ?>
			<div class="taxi-tabs-wrapper">
				<div class="nav nav-tabs taxi-tabs-tabs" id="nav-tab" role="tablist">
					<?php 
					$x=0;
					foreach( $settings['features_list_2'] as $data ): 
					$x++;
					$active = ($x == '1') ? 'active':'';
					?>
					<button class="nav-link <?php echo esc_attr($active) ?>" id="nav-step<?php echo esc_attr($x); ?>-tab" data-bs-toggle="tab" data-bs-target="#nav-step<?php echo esc_attr($x); ?>" type="button"><?php echo esc_html( $data['title'] ); ?></button>
					<?php endforeach; ?>
				</div>
				<div class="tab-content" id="nav-tabContent">
					<?php 
					$x=0;
					foreach( $settings['features_list_2'] as $data ): 
					$x++;
					$active = ($x == '1') ? 'active show ':'';
					?>
					<div class="tab-pane fade <?php echo esc_attr($active) ?>" id="nav-step<?php echo esc_attr($x); ?>" role="tabpanel">
						<div class="taxi-list">
							<p class="taxi-title"><?php echo esc_html( $data['desc'] ); ?></p>
							<div class="taxi-list_wrapper">
								<div class="taxi-img">
									<?php echo taxiar_img_tag( array(
										'url'   => esc_url( $data['image']['url']  ),
									)); ?>
								</div>
								<div class="checklist">
									<?php echo wp_kses_post($data['feature']); ?>
									<?php if(!empty($data['button_text'])): ?>
										<a href="<?php echo esc_url( $data['button_link']['url'] ); ?>" class="th-btn radius-btn"><?php echo wp_kses_post($data['button_text']); ?></a>
									<?php endif; ?>
								</div>
							</div>
						</div>
					</div>
					<?php endforeach; ?>
				</div>
			</div>

		<?php elseif( $settings['layout_style'] == '3' ): ?>
			<div class="service-feature-wrap">
				<?php foreach( $settings['features_list'] as $data ): ?>
				<div class="service-feature style2">
					<div class="service-feature_icon">
						<?php echo taxiar_img_tag( array(
								'url'   => esc_url( $data['icon']['url']  ),
							)); ?>
					</div>
					<div class="service-feature_content">
						<h4 class="service-feature_title th-title"><?php echo esc_html( $data['title'] ); ?></h4>
						<p class="service-feature_text th-desc"><?php echo esc_html( $data['desc'] ); ?></p>
					</div>
				</div>
				<?php endforeach; ?>
			</div>

        <?php else: ?>
			<div class="about-feature-wrap style2">
				<?php foreach( $settings['features_list'] as $data ): ?>
				<div class="about-feature">
					<div class="about-icon">
						<?php echo taxiar_img_tag( array(
								'url'   => esc_url( $data['icon']['url']  ),
							)); ?>
					</div>
					<div class="media-body">
						<h3 class="about_title th-title"><?php echo esc_html( $data['title'] ); ?></h3>
						<p class="about_text th-desc"><?php echo esc_html( $data['desc'] ); ?></p>
					</div>
				</div>
				<?php endforeach; ?>
			</div>

    <?php endif;
			
	}
}