<?php
/**
 * @Packge     : Taxiar
 * @Version    : 1.0
 * @Author     : Themeholy
 * @Author URI : https://themeforest.net/user/themeholy
 *
 */


// Block direct access
if( ! defined( 'ABSPATH' ) ){
    exit;
}

 // theme option callback
function taxiar_opt( $id = null, $url = null ){
    global $taxiar_opt;

    if( $id && $url ){

        if( isset( $taxiar_opt[$id][$url] ) && $taxiar_opt[$id][$url] ){
            return $taxiar_opt[$id][$url];
        }
    }else{
        if( isset( $taxiar_opt[$id] )  && $taxiar_opt[$id] ){
            return $taxiar_opt[$id];
        }
    }
}


// theme logo
function taxiar_theme_logo() {
    // escaping allow html
    $allowhtml = array(
        'a'    => array(
            'href' => array()
        ),
        'span' => array(),
        'i'    => array(
            'class' => array()
        )
    );
    $siteUrl = home_url('/');
    if( has_custom_logo() ) {
        $custom_logo_id = get_theme_mod( 'custom_logo' );
        $siteLogo = '';
        $siteLogo .= '<a class="logo" href="'.esc_url( $siteUrl ).'">';
        $siteLogo .= taxiar_img_tag( array(
            "class" => "img-fluid",
            "url"   => esc_url( wp_get_attachment_image_url( $custom_logo_id, 'full') )
        ) );
        $siteLogo .= '</a>';

        return $siteLogo;
    } elseif( !taxiar_opt('taxiar_text_title') && taxiar_opt('taxiar_site_logo', 'url' )  ){

        $siteLogo = '<img class="img-fluid" src="'.esc_url( taxiar_opt('taxiar_site_logo', 'url' ) ).'" alt="'.esc_attr__( 'logo', 'taxiar' ).'" />';
        return '<a class="logo" href="'.esc_url( $siteUrl ).'">'.$siteLogo.'</a>';


    }elseif( taxiar_opt('taxiar_text_title') ){
        return '<h2 class="mb-0"><a class="logo" href="'.esc_url( $siteUrl ).'">'.wp_kses( taxiar_opt('taxiar_text_title'), $allowhtml ).'</a></h2>';
    }else{
        return '<h2 class="mb-0"><a class="logo" href="'.esc_url( $siteUrl ).'">'.esc_html( get_bloginfo('name') ).'</a></h2>';
    }
}

// custom meta id callback
function taxiar_meta( $id = '' ){
    $value = get_post_meta( get_the_ID(), '_taxiar_'.$id, true );
    return $value;
}


// Blog Date Permalink
function taxiar_blog_date_permalink() {
    $year  = get_the_time('Y');
    $month_link = get_the_time('m');
    $day   = get_the_time('d');
    $link = get_day_link( $year, $month_link, $day);
    return $link;
}

//audio format iframe match
function taxiar_iframe_match() {
    $audio_content = taxiar_embedded_media( array('audio', 'iframe') );
    $iframe_match = preg_match("/\iframe\b/i",$audio_content, $match);
    return $iframe_match;
}


//Post embedded media
function taxiar_embedded_media( $type = array() ){
    $content = do_shortcode( apply_filters( 'the_content', get_the_content() ) );
    $embed   = get_media_embedded_in_content( $content, $type );


    if( in_array( 'audio' , $type) ){
        if( count( $embed ) > 0 ){
            $output = str_replace( '?visual=true', '?visual=false', $embed[0] );
        }else{
           $output = '';
        }

    }else{
        if( count( $embed ) > 0 ){
            $output = $embed[0];
        }else{
           $output = '';
        }
    }
    return $output;
}


// WP post link pages
function taxiar_link_pages(){
    wp_link_pages( array(
        'before'      => '<div class="page-links"><span class="page-links-title">' . esc_html__( 'Pages:', 'taxiar' ) . '</span>',
        'after'       => '</div>',
        'link_before' => '<span>',
        'link_after'  => '</span>',
        'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'taxiar' ) . ' </span>%',
        'separator'   => '<span class="screen-reader-text">, </span>',
    ) );
}


// Data Background image attr
function taxiar_data_bg_attr( $imgUrl = '' ){
    return 'data-bg-img="'.esc_url( $imgUrl ).'"';
}

// image alt tag
function taxiar_image_alt( $url = '' ){
    if( $url != '' ){
        // attachment id by url
        $attachmentid = attachment_url_to_postid( esc_url( $url ) );
       // attachment alt tag
        $image_alt = get_post_meta( esc_html( $attachmentid ) , '_wp_attachment_image_alt', true );
        if( $image_alt ){
            return $image_alt ;
        }else{
            $filename = pathinfo( esc_url( $url ) );
            $alt = str_replace( '-', ' ', $filename['filename'] );
            return $alt;
        }
    }else{
       return;
    }
}


// Flat Content wysiwyg output with meta key and post id

function taxiar_get_textareahtml_output( $content ) {
    global $wp_embed;

    $content = $wp_embed->autoembed( $content );
    $content = $wp_embed->run_shortcode( $content );
    $content = wpautop( $content );
    $content = do_shortcode( $content );

    return $content;
}

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */

function taxiar_pingback_header() {
    if ( is_singular() && pings_open() ) {
        echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'taxiar_pingback_header' );


// Excerpt More
function taxiar_excerpt_more( $more ) {
    return '...';
}

add_filter( 'excerpt_more', 'taxiar_excerpt_more' );


// taxiar comment template callback
function taxiar_comment_callback( $comment, $args, $depth ) {
        $add_below = 'comment';
    ?>
    <li <?php comment_class( array('th-comment-item') ); ?>>
        <div id="comment-<?php comment_ID() ?>" class="th-post-comment">
            <?php
                if( get_avatar( $comment, 100 )  ) :
            ?>
            <!-- Author Image -->
            <div class="comment-avater">
                <?php
                    if ( $args['avatar_size'] != 0 ) {
                        echo get_avatar( $comment, 110 );
                    }
                ?>
            </div>
            <!-- Author Image -->
            <?php endif; ?>
            <!-- Comment Content -->
            <div class="comment-content">
                <span class="commented-on"><?php printf( esc_html__('%1$s-%2$s', 'taxiar'), get_comment_date(), get_the_time() ); ?></span>
                <h3 class="name"><?php echo esc_html( ucwords( get_comment_author() ) ); ?></h3>
                <p class="text"><?php echo get_comment_text(); ?></p>
                <div class="reply_and_edit">
                    <?php
                        $reply_text = wp_kses_post( '<i class="fas fa-reply"></i> Reply', 'taxiar' );

                        $edit_reply_text = wp_kses_post( '<i class="fas fa-pencil-alt"></i> Edit', 'taxiar' );

                        comment_reply_link(array_merge( $args, array( 'add_below' => $add_below, 'depth' => 3, 'max_depth' => 5, 'reply_text' => $reply_text ) ) );
                    ?>  
                </div>
                <?php if ( $comment->comment_approved == '0' ) : ?>
                <p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'taxiar' ); ?></p>
                <?php endif; ?>
            </div>
        </div>
        <!-- Comment Content -->
<?php
}

//body class
add_filter( 'body_class', 'taxiar_body_class' );
function taxiar_body_class( $classes ) {
    if( class_exists('ReduxFramework') ) {
        $taxiar_blog_single_sidebar = taxiar_opt('taxiar_blog_single_sidebar');
        if( ($taxiar_blog_single_sidebar != '2' && $taxiar_blog_single_sidebar != '3' ) || ! is_active_sidebar('taxiar-blog-sidebar') ) {
            $classes[] = 'no-sidebar';
        }
        $new_class = is_page() ? taxiar_meta('custom_body_class') : null;

        if ( $new_class ) {
            $classes[] = $new_class;
        }
    } else {
        if( !is_active_sidebar('taxiar-blog-sidebar') ) {
            $classes[] = 'no-sidebar';
        }
    }
    $classes[] = 'dark-theme';
    return $classes;
}

//Global Footer
function taxiar_footer_global_option(){
    // Taxiar Widget Enable Disable
    if( class_exists( 'ReduxFramework' ) ){
        $taxiar_footer_widget_enable = taxiar_opt( 'taxiar_footerwidget_enable' );
        $taxiar_footer_bottom_active = taxiar_opt( 'taxiar_disable_footer_bottom' );
    }else{
        $taxiar_footer_widget_enable = '';
        $taxiar_footer_bottom_active = '1';
    }
    $allowhtml = array(
        'p'         => array(
            'class'     => array()
        ),
        'i'         => array(
            'class'     => array()
        ),
        'span'      => array(
            'class'     => array(),
        ),
        'a'         => array(
            'href'      => array(),
            'title'     => array(),
            'class'     => array(),
        ),
        'br'        => array(),
        'em'        => array(),
        'strong'    => array(),
        'b'         => array(),
    );
    if( $taxiar_footer_widget_enable == '1' || $taxiar_footer_bottom_active == '1' ){
        echo '<!---footer-wrapper start-->';
        echo '<footer class="footer-wrapper footer-layout7" data-bg-src="'.esc_url( taxiar_opt('taxiar_footer_background', 'background-image' ) ).'">';
            if( $taxiar_footer_widget_enable == '1' ){
                if( ( is_active_sidebar( 'taxiar-footer-1' ) || is_active_sidebar( 'taxiar-footer-2' ) || is_active_sidebar( 'taxiar-footer-3' ) )) {
                    echo '<div class="widget-area">';
                        echo '<div class="container">';
                                echo '<div class="row justify-content-between">';
                                    if( is_active_sidebar( 'taxiar-footer-1' )){
                                    dynamic_sidebar( 'taxiar-footer-1' ); 
                                    }
                                    if( is_active_sidebar( 'taxiar-footer-2' )){
                                    dynamic_sidebar( 'taxiar-footer-2' ); 
                                    }
                                    if( is_active_sidebar( 'taxiar-footer-3' )){
                                    dynamic_sidebar( 'taxiar-footer-3' ); 
                                    } 
                                    if( is_active_sidebar( 'taxiar-footer-4' )){
                                    dynamic_sidebar( 'taxiar-footer-4' ); 
                                    }  
                                echo '</div>';
                        echo '</div>';
                    echo '</div>';
                }
            }

            if( $taxiar_footer_bottom_active == '1' ){
                echo '<div class="copyright-wrap">';
                    echo '<div class="container">';
                            echo '<p class="copyright-text">'.wp_kses( taxiar_opt( 'taxiar_copyright_text' ), $allowhtml ).'</p>';
                    echo '</div>';
                echo '</div>';
            }

            echo '<div class="footer-shape">';
                echo taxiar_img_tag( array(
                    "url"   => taxiar_opt('taxiar_footer_shape', 'url'),
                ) );
            echo '</div>';

        echo '</footer>';
        echo '<!---footer-wrapper end-->';
    }
}

// Social link
function taxiar_social_icon(){
    $taxiar_social_icon = taxiar_opt( 'taxiar_social_links' );
    if( ! empty( $taxiar_social_icon ) && isset( $taxiar_social_icon ) ){
        foreach( $taxiar_social_icon as $social_icon ){
                echo '<a href="'.esc_url( $social_icon['url'] ).'"><i class="'.esc_attr( $social_icon['title'] ).'"></i>'.esc_attr( $social_icon['description'] ).'</a>';
        }
    }
}


// global header
function taxiar_global_header_option() {

    if( class_exists( 'ReduxFramework' ) ){ ?>
        <header class="th-header header-layout7 prebuilt">
        <?php
        if(taxiar_opt( 'taxiar_header_sticky_switcher' )){
            $sticky_class  = 'yes-sticky';
        }else{
            $sticky_class  = 'no-sticky';
        }
        echo taxiar_header_cart_offcanvas();
        echo taxiar_header_offcanvas();
        echo taxiar_mobile_menu();
        echo taxiar_search_box();

        echo taxiar_header_menu_topbar();
        ?>
            <div class="sticky-wrapper <?php echo esc_attr( $sticky_class ); ?>">
                <div class="menu-area">
                    <div class="container">
                        <div class="row justify-content-between align-items-center">
                            <div class="col-auto">
                                <div class="header-logo">
                                    <?php echo taxiar_theme_logo(); ?>
                                </div>
                            </div>
                            <div class="col-auto me-xl-auto">
                                <nav class="main-menu d-none d-lg-block">
                                    <?php 
                                        wp_nav_menu( array(
                                            "theme_location"    => 'primary-menu',
                                            "container"         => '',
                                            "menu_class"        => ''
                                        ) ); 
                                    ?>
                                </nav>
                                <button class="th-menu-toggle  d-inline-block d-lg-none"><i class="far fa-bars"></i></button>
                            </div>
                            <div class="col-auto d-none d-xl-block">
                                <div class="header-button">
                                    <?php if(!empty(taxiar_opt( 'taxiar_header_search_switcher' )) ): ?>
                                        <button type="button" class="icon-btn searchBoxToggler"><i class="far fa-search"></i></button>
                                    <?php endif; ?> 
                                    <?php if(!empty(taxiar_opt( 'taxiar_header_cart_switcher' )) ): 
                                            if( class_exists( 'woocommerce' ) ):
                                                global $woocommerce;
                                                if( ! empty( $woocommerce->cart->cart_contents_count ) ){
                                                    $count = $woocommerce->cart->cart_contents_count;
                                                }else{
                                                    $count = "0";
                                                }
                                        ?>
                                        <button type="button" class="icon-btn sideMenuToggler2">
                                            <i class="fa-regular fa-bag-shopping"></i>
                                            <span class="badge"><?php echo esc_html( $count ) ?></span>
                                        </button>
                                    <?php endif; endif; ?> 
                                    <?php if(!empty(taxiar_opt( 'taxiar_header_offcanvas_switcher' )) ): ?>
                                        <a href="#" class="icon-btn sideMenuToggler"><i class="far fa-bars"></i></a>
                                    <?php endif; ?> 
                                    <?php 
                                        if(!empty(taxiar_opt( 'taxiar_btn_switcher' )) && !empty(taxiar_opt( 'taxiar_btn_text' )) ): 
                                        ?>
                                        <div class="header-button">
                                            <a href="<?php echo esc_url(taxiar_opt( 'taxiar_btn_url' )) ?>" class="th-btn th_btn"><?php echo wp_kses_post(taxiar_opt( 'taxiar_btn_text' )) ?></a>
                                        </div>
                                    <?php endif; ?> 
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php if(!empty(taxiar_opt('taxiar_logo_shape', 'url' ) )): ?>
            <div class="logo-shape">
                <?php echo taxiar_img_tag( array(
                    "url"   => taxiar_opt('taxiar_logo_shape', 'url'),
                ) ); ?>
            </div>
            <?php endif; ?>

        </header>
    <?php
    }else{
        echo taxiar_global_header();
    }
}

if( ! function_exists( 'taxiar_header_menu_topbar' ) ){
    function taxiar_header_menu_topbar(){
        if( class_exists( 'ReduxFramework' ) ){
            $taxiar_header_topbar_switcher  = taxiar_opt( 'taxiar_header_topbar_switcher' );
            $taxiar_show_lang_switcher        = taxiar_opt( 'taxiar_header_lang_switcher' );
            $taxiar_show_social_switcher      = taxiar_opt( 'taxiar_header_social_switcher' );
        }else{
            $taxiar_header_topbar_switcher  = '';
            $taxiar_show_lang_switcher        = '';
            $taxiar_show_social_switcher        = '';
        }

        if( $taxiar_header_topbar_switcher ){
            $allowhtml = array(
                'a'    => array(
                    'href' => array(),
                    'class' => array()
                ),
                'u'    => array(
                    'class' => array()
                ),
                'span' => array(
                    'class' => array()
                ),
                'i'    => array(
                    'class' => array()
                )
            );
            $phone     = taxiar_opt( 'taxiar_topbar_phone' );
            $email     = taxiar_opt( 'taxiar_topbar_email' );

            $email          = is_email( $email );

            $replace        = array(' ','-',' - ');
            $replace_phoone = array(' ','-',' - ', '(', ')');
            $with           = array('','','');

            $phoneurl       = str_replace( $replace_phoone, $with, $phone );
            $emailurl       = str_replace( $replace, $with, $email );

            $phone_icon     = taxiar_opt( 'taxiar_topbar_phone_icon' );
            $email_icon     = taxiar_opt( 'taxiar_topbar_email_icon' );

            ?>
            <div class="header-top">
                <div class="container">
                    <div class="row justify-content-center justify-content-md-between align-items-center gy-2">
                        <div class="col-auto d-none d-md-block">
                            <div class="header-links">
                                <ul>
                                    <li><?php echo wp_kses_post($phone_icon); ?><a href="<?php echo esc_attr('mailto:' . $emailurl); ?>"><?php echo esc_html( $email ); ?></a>
                                    </li>
                                    <li><?php echo wp_kses_post($email_icon); ?><a href="<?php echo esc_attr( 'tel:'.$phoneurl ) ?>"><?php echo esc_html( $phone ); ?></a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                        <div class="col-auto">
                            <div class="header-right">
                                <?php if(!empty($taxiar_show_lang_switcher) ): ?>
                                <div class="langauge lang-dropdown">
                                    <a class="dropdown-toggle" href="#" role="button" id="dropdownMenuLink1" data-bs-toggle="dropdown" aria-expanded="false"><?php echo esc_html__( 'Language', 'taxiar' );?></a>
				                        <div class="list dropdown-menu" aria-labelledby="dropdownMenuLink1">
				                            <?php  echo do_shortcode('[gtranslate]'); ?>
				                        </div>
                                </div>
                                <?php endif; ?>
                                <?php if(!empty($taxiar_show_social_switcher) ): ?>
                                <div class="header-social">
                                    <span class="social-title"><?php echo esc_html(taxiar_opt( 'taxiar_header_topbar_social_text' )); ?></span>
                                    <?php echo taxiar_social_icon(); ?>
                                </div>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
         
        <?php
        }
    }
}

// taxiar woocommerce breadcrumb
function taxiar_woo_breadcrumb( $args ) {
    return array(
        'delimiter'   => '',
        'wrap_before' => '<ul class="breadcumb-menu">',
        'wrap_after'  => '</ul>',
        'before'      => '<li>',
        'after'       => '</li>',
        'home'        => _x( 'Home', 'breadcrumb', 'taxiar' ),
    );
}

add_filter( 'woocommerce_breadcrumb_defaults', 'taxiar_woo_breadcrumb' );

function taxiar_custom_search_form( $class ) {
    echo '<!-- Search Form -->';

    echo '<form role="search" method="get" action="'.esc_url( home_url( '/' ) ).'" class="'.esc_attr( $class ).'">';
        echo '<label class="searchIcon">';
            echo taxiar_img_tag( array(
                "url"   => esc_url( get_theme_file_uri( '/assets/img/search-2.svg' ) ),
                "class" => "svg"
            ) );
            echo '<input value="'.esc_html( get_search_query() ).'" name="s" required type="search" placeholder="'.esc_attr__('What are you looking for?', 'taxiar').'">';
        echo '</label>';
    echo '</form>';
    echo '<!-- End Search Form -->';
}



//Fire the wp_body_open action.
if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
        do_action( 'wp_body_open' );
    }
}

//Remove Tag-Clouds inline style
add_filter( 'wp_generate_tag_cloud', 'taxiar_remove_tagcloud_inline_style',10,1 );
function taxiar_remove_tagcloud_inline_style( $input ){
   return preg_replace('/ style=("|\')(.*?)("|\')/','',$input );
}

/* This code filters the Categories archive widget to include the post count inside the link */
add_filter( 'wp_list_categories', 'taxiar_cat_count_span' );
function taxiar_cat_count_span( $links ) {
    $links = str_replace('</a> (', '</a> <span class="category-number">', $links);
    $links = str_replace(')', '</span>', $links);
    return $links;
}

/* This code filters the Archive widget to include the post count inside the link */
add_filter( 'get_archives_link', 'taxiar_archive_count_span' );
function taxiar_archive_count_span( $links ) {
    $links = str_replace('</a>&nbsp;(', '</a> <span class="category-number">', $links);
    $links = str_replace(')', '</span>', $links);
    return $links;
}

//header search box
if(! function_exists('taxiar_search_box')){
    function taxiar_search_box(){
        echo '<div class="popup-search-box d-none d-lg-block">';
            echo '<button class="searchClose"><i class="fal fa-times"></i></button>';
            echo '<form role="search" method="get" action="'.esc_url( home_url( '/' ) ).'">';
                echo '<input value="'.esc_html( get_search_query() ).'" name="s" required type="search" placeholder="'.esc_attr__('What are you looking for?', 'taxiar').'">';
                echo '<button type="submit"><i class="fal fa-search"></i></button>';
            echo '</form>';
        echo '</div>';
    }
}


// Taxiar Default Header
if( ! function_exists( 'taxiar_global_header' ) ){
    function taxiar_global_header(){ ?>

        <!--Mobile menu & Search box-->
        <?php 
        echo taxiar_search_box(); 
        echo taxiar_mobile_menu(); 
        
        ?>

        <!--======== Header ========-->
        <header class="th-header header-layout1 unittest-header">
            <div class="sticky-wrapper">
                <div class="sticky-active">
                    <div class="menu-area">
                        <div class="container">
                            <div class="row gx-20 align-items-center justify-content-between">

                                <div class="col-auto">
                                    <div class="header-logo">
                                       <?php echo taxiar_theme_logo(); ?>
                                    </div>
                                </div>

                                <div class="col-auto">
                                    <?php
                                    if( has_nav_menu( 'primary-menu' ) ) { ?>
                                        <nav class="main-menu d-none d-lg-inline-block">
                                            <?php
                                            wp_nav_menu( array(
                                                "theme_location"    => 'primary-menu',
                                                "container"         => '',
                                                "menu_class"        => ''
                                            ) ); ?>
                                        </nav>
                                    <?php } ?>                                   
                                    </nav>
                                    <button type="button" class="th-menu-toggle d-inline-block d-lg-none"><i class="far fa-bars"></i></button>
                                </div>
                                <div class="col-auto d-none d-xl-block">
                                    <div class="header-button">
                                        <button type="button" class="icon-btn searchBoxToggler"><i class="far fa-search"></i></button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="menu-bg"></div>
                </div>
            </div>
        </header>
    <?php
    }
}


//header Offcanvas
if( ! function_exists( 'taxiar_header_offcanvas' ) ){
    function taxiar_header_offcanvas(){
    ?>
    <div class="sidemenu-wrapper side-offcanvas d-none d-lg-block  ">
        <div class="sidemenu-content bg-title">
            <button class="closeButton sideMenuCls"><i class="far fa-times"></i></button>
            <?php 
                if(is_active_sidebar('taxiar-offcanvas')){
                    dynamic_sidebar( 'taxiar-offcanvas' );
                }else{
                    echo '<h4 class="widget_title text-white">No Widget Added </h4>';
                    echo '<p>Please add some widget in Offcanvs Sidebar</p>';
                }
            ?>
        </div>
    </div>
    
<?php
    }
}

//header Cart Offcanvas
if( ! function_exists( 'taxiar_header_cart_offcanvas' ) ){
    function taxiar_header_cart_offcanvas(){
        ?>
        <div class="sidemenu-wrapper shopping-cart d-none d-lg-block  ">
            <div class="sidemenu-content">
                <button class="closeButton sideMenuCls"><i class="far fa-times"></i></button>
                <div class="widget woocommerce widget_shopping_cart">
                    <h3 class="widget_title"><?php echo esc_html__( 'Shopping cart', 'taxiar' ); ?></h3>
                    <div class="widget_shopping_cart_content">
                    
                    </div>
                </div>
            </div>
        </div>

    <?php
    }
}

// mobile logo
function taxiar_mobile_logo() {
    $logo_url = taxiar_opt('taxiar_mobile_logo', 'url' );
    $mobile_menu = '';
    if( !empty($logo_url )){
        $mobile_menu = '<div class="mobile-logo"><a href="'.home_url('/').'"><img src="'.esc_url($logo_url).'" alt="'.esc_attr__( 'logo', 'taxiar' ).'"></a></div>';
    }else{
        $mobile_menu .= '<div class="mobile-logo">';
        $mobile_menu .= taxiar_theme_logo();
        $mobile_menu .= '</div>';
    }

    return $mobile_menu;
 }

//header Mobile Menu
if( ! function_exists( 'taxiar_mobile_menu' ) ){
    function taxiar_mobile_menu(){
    ?>
    <div class="th-menu-wrapper">
        <div class="th-menu-area text-center">
            <button class="th-menu-toggle"><i class="fal fa-times"></i></button>
            <?php  if( class_exists('ReduxFramework') ):?>
                <?php 
                    if(!empty(taxiar_opt('taxiar_menu_menu_show') )){
                        echo taxiar_mobile_logo(); 
                    }
                ?>
            <?php else: ?>
                <div class="mobile-logo">
                    <?php echo taxiar_theme_logo(); ?>
                </div>
            <?php endif; ?>
            <div class="th-mobile-menu">
                <?php 
                    if( has_nav_menu( 'primary-menu' ) ){
                        wp_nav_menu( array(
                            "theme_location"    => 'primary-menu',
                            "container"         => '',
                            "menu_class"        => ''
                        ) );
                    }
                ?>
            </div>
        </div>
    </div>

<?php
    }
}



// Blog post views function
function taxiar_setPostViews( $postID ) {
    $count_key  = 'post_views_count';
    $count      = get_post_meta( $postID, $count_key, true );
    if( $count == '' ){
        $count = 0;
        delete_post_meta( $postID, $count_key );
        add_post_meta( $postID, $count_key, '0' );
    }else{
        $count++;
        update_post_meta( $postID, $count_key, $count );
    }
}

function taxiar_getPostViews( $postID ){
    $count_key  = 'post_views_count';
    $count      = get_post_meta( $postID, $count_key, true );
    if( $count == '' ){
        delete_post_meta( $postID, $count_key );
        add_post_meta( $postID, $count_key, '0' );
        return __( '0', 'taxiar' );
    }
    return $count;
}


// Add Extra Class On Comment Reply Button
function taxiar_custom_comment_reply_link( $content ) {
    $extra_classes = 'reply-btn';
    return preg_replace( '/comment-reply-link/', 'comment-reply-link ' . $extra_classes, $content);
}

add_filter('comment_reply_link', 'taxiar_custom_comment_reply_link', 99);

// Add Extra Class On Edit Comment Link
function taxiar_custom_edit_comment_link( $content ) {
    $extra_classes = 'reply-btn';
    return preg_replace( '/comment-edit-link/', 'comment-edit-link ' . $extra_classes, $content);
}

add_filter('edit_comment_link', 'taxiar_custom_edit_comment_link', 99);


function taxiar_post_classes( $classes, $class, $post_id ) {
    if ( get_post_type() === 'post' ) {
        $classes[] = "th-blog blog-single has-post-thumbnail";
    }elseif( get_post_type() === 'product' ){
        // Return Class
    }elseif( get_post_type() === 'page' ){
        $classes[] = "page--item";
    }
    
    return $classes;
}
add_filter( 'post_class', 'taxiar_post_classes', 10, 3 );

// Contact form 7
add_filter('wpcf7_autop_or_not', '__return_false');