<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * Contact Form Widget .
 *
 */
class taxiar_Contact_Form extends Widget_Base {

	public function get_name() {
		return 'taxiarcontactform';
	}
	public function get_title() {
		return __( 'Contact Form', 'taxiar' );
	}
	public function get_icon() {
		return 'th-icon';
    }
	public function get_categories() {
		return [ 'taxiar' ];
	}

	public function get_as_contact_form(){
        if ( ! class_exists( 'WPCF7' ) ) {
            return;
        }
        $as_cfa         = array();
        $as_cf_args     = array( 'posts_per_page' => -1, 'post_type'=> 'wpcf7_contact_form' );
        $as_forms       = get_posts( $as_cf_args );
        $as_cfa         = ['0' => esc_html__( 'Select Form', 'taxiar' ) ];
        if( $as_forms ){
            foreach ( $as_forms as $as_form ){
                $as_cfa[$as_form->ID] = $as_form->post_title;
            }
        }else{
            $as_cfa[ esc_html__( 'No contact form found', 'taxiar' ) ] = 0;
        }
        return $as_cfa;
    }

	protected function register_controls() {

		$this->start_controls_section(
			'contact_form_section',
			[
				'label' 	=> __( 'Contact Form', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
			'layout_style',
			[
				'label' 	=> __( 'Layout Style', 'taxiar' ),
				'type' 		=> Controls_Manager::SELECT,
				'default' 	=> '1',
				'options' 	=> [
					'1'  		=> __( 'Style One', 'taxiar' ),
					'2' 		=> __( 'Style Two', 'taxiar' ),
					'3' 		=> __( 'Style Three', 'taxiar' ),
					'4' 		=> __( 'Style Four', 'taxiar' ),
					'5' 		=> __( 'Style Five', 'taxiar' ),
					'6' 		=> __( 'Style Six', 'taxiar' ),
				],
			]
		);  

		$this->add_control(
            'bg',
            [
                'label'     => __( 'Background', 'taxiar' ),
                'type'      => Controls_Manager::MEDIA,
                'dynamic' 		=> [
					'active' 		=> true,
				],
				'condition'	=> [
					'layout_style' => ['2', '3'],
				]
            ]
        );

		$this->add_control(
            'image',
            [
                'label'     => __( 'Image', 'taxiar' ),
                'type'      => Controls_Manager::MEDIA,
                'dynamic' 		=> [
					'active' 		=> true,
				],
				'condition'	=> [
					'layout_style' => ['3'],
				]
            ]
        );

		$this->add_control(
            'image2',
            [
                'label'     => __( 'Image 2', 'taxiar' ),
                'type'      => Controls_Manager::MEDIA,
                'dynamic' 		=> [
					'active' 		=> true,
				],
				'condition'	=> [
					'layout_style' => ['3'],
				]
            ]
        );
		
		$this->add_control(
			'section_subtitle',
			[
				'label' 	=> __( 'Section Subitle', 'taxiar' ),
                'type' 		=> Controls_Manager::TEXTAREA,
                'default'  	=> __( 'Section Subtiitle', 'taxiar' ),
				'rows' => '2',
				'condition'	=> [
					'layout_style' => ['3'],
				]
			]
        );

		$this->add_control(
            'subtitle_shape',
            [
                'label'     => __( 'Subtitle Shape', 'taxiar' ),
                'type'      => Controls_Manager::MEDIA,
                'dynamic' 		=> [
					'active' 		=> true,
				],
				'condition'	=> [
					'layout_style' => ['3'],
				]
            ]
        );

		$this->add_control(
			'section_title',
			[
				'label' 	=> __( 'Title', 'taxiar' ),
                'type' 		=> Controls_Manager::TEXTAREA,
                'default'  	=> __( 'Section Title', 'taxiar' ),
				'rows' => '2',
				'condition'	=> [
					'layout_style' => ['2', '3', '5', '6'],
				]
			]
        );

		$this->add_control(
			'section_desc',
			[
				'label' 	=> __( 'Description', 'taxiar' ),
                'type' 		=> Controls_Manager::TEXTAREA,
                'default'  	=> __( 'Description', 'taxiar' ),
				'rows' => '4',
				'condition'	=> [
					'layout_style' => ['5'],
				]
			]
        );

		$this->add_control(
			'title',
			[
				'label' 	=> __( 'Left Title', 'taxiar' ),
                'type' 		=> Controls_Manager::TEXTAREA,
                'default'  	=> __( 'Left Title', 'taxiar' ),
				'rows' => '2',
				'condition'	=> [
					'layout_style' => ['3'],
				]
			]
        );

		$this->add_control(
            'taxiar_select_contact_form',
            [
                'label'   => esc_html__( 'Select Form', 'taxiar' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '0',
                'options' => $this->get_as_contact_form(),
            ]
        );

        $this->end_controls_section();

        //---------------------------------------
			//Style Section Start
		//---------------------------------------

		//-------------------------General Style-----------------------//
        $this->start_controls_section(
			'style',
			[
				'label' => __( 'Style', 'taxiar' ),
				'tab' 	=> Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'general_bg',
			[
				'label' 		=> __( 'Background Color', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .th-bg' => 'background: {{VALUE}}!important',
                ],
			]
        );

       $this->add_responsive_control(
			'general_padding',
			[
				'label' 		=> __( 'Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th-bg' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );
		
        $this->end_controls_section();

		//-------------------------Subtitle Style-----------------------//
		$this->start_controls_section(
			'subtitle_style',
			[
				'label' 	=> __( 'Subtitle Style', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
				'condition'	=> [
					'layout_style' => ['3'],
				]
			]
		);

		$this->add_control(
			'subtitle_color',
			[
				'label' 		=> __( 'Color', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .th-sub' => 'color: {{VALUE}} !important',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'subtitle_typography',
				'label' 	=> __( 'Typography', 'taxiar' ),
				'selector' 	=> '{{WRAPPER}} .th-sub',
			]
		);

		$this->add_responsive_control(
			'subtitle_margin',
			[
				'label' 		=> __( 'Margin', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th-sub' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->add_responsive_control(
			'subtitle_padding',
			[
				'label' 		=> __( 'Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th-sub' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->end_controls_section();

		//-------------------------Title Style-----------------------//
		$this->start_controls_section(
			'title_style',
			[
				'label' 	=> __( 'Title Style', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
				'condition'	=> [
					'layout_style' => ['2', '3', '5', '6'],
				]
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' 		=> __( 'Color', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .th-title' => 'color: {{VALUE}} !important',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'title_typography',
				'label' 	=> __( 'Typography', 'taxiar' ),
				'selector' 	=> '{{WRAPPER}} .th-title',
			]
		);

		$this->add_responsive_control(
			'title_margin',
			[
				'label' 		=> __( 'Margin', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->add_responsive_control(
			'title_padding',
			[
				'label' 		=> __( 'Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->end_controls_section();

		//-------------------------Title Style-----------------------//
		$this->start_controls_section(
			'desc_style',
			[
				'label' 	=> __( 'Description Style', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
				'condition'	=> [
					'layout_style' => ['5'],
				]
			]
		);

		$this->add_control(
			'desc_color',
			[
				'label' 		=> __( 'Color', 'taxiar' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .th-desc' => 'color: {{VALUE}} !important',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'desc_typography',
				'label' 	=> __( 'Typography', 'taxiar' ),
				'selector' 	=> '{{WRAPPER}} .th-desc',
			]
		);

		$this->add_responsive_control(
			'desc_margin',
			[
				'label' 		=> __( 'Margin', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th-desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->add_responsive_control(
			'desc_padding',
			[
				'label' 		=> __( 'Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th-desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->end_controls_section();

		//-------------------------Button Style-----------------------//
		$this->start_controls_section(
			'button_style_section',
			[
				'label' 	=> __( 'Button Style', 'taxiar' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'button_typography',
				'label' 	=> __( 'Typography', 'taxiar' ),
				'selector' 	=> '{{WRAPPER}} .th_btn',
			]
		);

		$this->start_controls_tabs(
			'style_tabs'
		);

			$this->start_controls_tab(
				'first_style_tab',
				[
					'label' => esc_html__( 'Normal', 'taxiar' ),
				]
			);

			$this->add_control(
				'button_color',
				[
					'label' 		=> __( 'Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn' => 'color: {{VALUE}}',
					],
				]
			);
	
			$this->add_control(
				'button_bg',
				[
					'label' 		=> __( 'Background Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn' => 'background-color:{{VALUE}}',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border',
					'selector' => '{{WRAPPER}} .th_btn',
				]
			);

			$this->end_controls_tab();

			//--------------------secound--------------------//
			$this->start_controls_tab(
				'sec_style_tab',
				[
					'label' => esc_html__( 'Hover', 'taxiar' ),
				]
			);

			$this->add_control(
				'button_h_color',
				[
					'label' 		=> __( 'Hover Color ', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn:hover' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'button_h_bg',
				[
					'label' 		=> __( 'Background Hover Color', 'taxiar' ),
					'type' 			=> Controls_Manager::COLOR,
					'selectors' 	=> [
						'{{WRAPPER}} .th_btn:before, {{WRAPPER}} .th_btn:after' => 'background-color:{{VALUE}} !important',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'border2',
					'selector' => '{{WRAPPER}} .th_btn:hover',
				]
			);

			$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_control(
			'hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_responsive_control(
			'button_margin',
			[
				'label' 		=> __( 'Margin', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th_btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->add_responsive_control(
			'button_padding',
			[
				'label' 		=> __( 'Padding', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th_btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);
		
		$this->add_responsive_control(
			'button_border_radius',
			[
				'label' 		=> __( 'Border Radius', 'taxiar' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .th_btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				]
			]
		);

		$this->end_controls_section();

	}

	protected function render() {

	    $settings = $this->get_settings_for_display();

	    ?>
		<?php if( $settings['layout_style'] == '2' ): ?>
			<div class="booking-form4 ajax-contact th-bg" data-bg-src="<?php echo esc_url($settings['bg']['url']); ?>">
				<h3 class="th-title"><?php echo esc_html($settings['section_title']) ?></h3>
				<?php 
					if( !empty($settings['taxiar_select_contact_form']) ){
						echo do_shortcode( '[contact-form-7  id="'.$settings['taxiar_select_contact_form'].'"]' ); 
					}else{
						echo '<div class="alert alert-warning"><p class="m-0">' . __('Please Select contact form.', 'taxiar' ). '</p></div>';
					}
				?>
			</div>

		<?php elseif( $settings['layout_style'] == '3' ): ?>
		<div class="booking-area2 position-relative bg-title space-top th-bg" data-bg-src="<?php echo esc_url($settings['bg']['url']); ?>">
			<div class="container">
				<div class="row">
					<div class="col-lg-5">
						<div class="booking-image-wrapper">
							<div class="booking-img">
								<?php echo taxiar_img_tag( array(
									'url'   => esc_url( $settings['image']['url']  ),
								)); ?>
							</div>
						</div>
					</div>
					<div class="col-xl-7 ps-xl-5 wow fadeInRight">
						<div class="booking-form5 ajax-contact">
							<div class="title-area mb-35 text-center text-lg-start">
								<span class="sub-title style2 th-sub">
									<?php echo taxiar_img_tag( array(
										'url'   => esc_url( $settings['subtitle_shape']['url']  ),
									)); ?>
									<?php echo esc_html($settings['section_subtitle']) ?>
								</span>
								<h2 class="sec-title text-white th-title"><?php echo esc_html($settings['section_title']) ?></h2>
							</div>
							<?php 
								if( !empty($settings['taxiar_select_contact_form']) ){
									echo do_shortcode( '[contact-form-7  id="'.$settings['taxiar_select_contact_form'].'"]' ); 
								}else{
									echo '<div class="alert alert-warning"><p class="m-0">' . __('Please Select contact form.', 'taxiar' ). '</p></div>';
								}
							?>
						</div>
					</div>
				</div>
			</div>
			<div class="booking-image">
				<?php echo taxiar_img_tag( array(
					'url'   => esc_url( $settings['image2']['url']  ),
				)); ?>
			</div>
			<div class="booking-content">
				<h3 class="booking-text"><?php echo esc_html($settings['title']) ?></h3>
			</div>
		</div>

		<?php elseif( $settings['layout_style'] == '4' ): ?>
			<?php 
				if( !empty($settings['taxiar_select_contact_form']) ){
					echo do_shortcode( '[contact-form-7  id="'.$settings['taxiar_select_contact_form'].'"]' ); 
				}else{
					echo '<div class="alert alert-warning"><p class="m-0">' . __('Please Select contact form.', 'taxiar' ). '</p></div>';
				}
			?>

		<?php elseif( $settings['layout_style'] == '5' ): ?>
			<div class="booking-form-area ajax-booking th-bg">
                <div class="booking-title-area">
                    <h4 class="booking-title th-title"><?php echo esc_html($settings['section_title']) ?></h4>
                    <p class="booking-desc th-desc"><?php echo esc_html($settings['section_desc']) ?></p>
                </div>
				<?php 
					if( !empty($settings['taxiar_select_contact_form']) ){
						echo do_shortcode( '[contact-form-7  id="'.$settings['taxiar_select_contact_form'].'"]' ); 
					}else{
						echo '<div class="alert alert-warning"><p class="m-0">' . __('Please Select contact form.', 'taxiar' ). '</p></div>';
					}
				?>
            </div>

		<?php elseif( $settings['layout_style'] == '6' ): ?>
			<div class="faq-sidebar">
				<div class="widget widget_quote th-bg">
					<h3 class="widget_title th-title"><?php echo esc_html($settings['section_title']) ?></h3>
					<div class="widget-form ajax-contact">
						<?php 
							if( !empty($settings['taxiar_select_contact_form']) ){
								echo do_shortcode( '[contact-form-7  id="'.$settings['taxiar_select_contact_form'].'"]' ); 
							}else{
								echo '<div class="alert alert-warning"><p class="m-0">' . __('Please Select contact form.', 'taxiar' ). '</p></div>';
							}
						?>
					</div>
				</div>
			</div>

		<?php else: ?>
			<div class="booking-form ajax-contact th-bg">
                <div class="input-wrap wow fadeInUp">
				<?php 
					if( !empty($settings['taxiar_select_contact_form']) ){
						echo do_shortcode( '[contact-form-7  id="'.$settings['taxiar_select_contact_form'].'"]' ); 
					}else{
						echo '<div class="alert alert-warning"><p class="m-0">' . __('Please Select contact form.', 'taxiar' ). '</p></div>';
					}
				?>
                </div>
            </div>
	    	 
	    <?php endif;

	}

}